/* Generated by Cython 0.29.21 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "name": "DataGenerator.DatasetGenerator.RootWordDataSetGenerator",
        "sources": [
            "DataGenerator/DatasetGenerator/RootWordDataSetGenerator.pyx"
        ]
    },
    "module_name": "DataGenerator.DatasetGenerator.RootWordDataSetGenerator"
}
END: Cython Metadata */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_29_21"
#define CYTHON_HEX_VERSION 0x001D15F0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
  #ifndef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS (PY_VERSION_HEX >= 0x030600B1)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK (PY_VERSION_HEX >= 0x030700A3)
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
#if PY_VERSION_HEX >= 0x030800A4 && PY_VERSION_HEX < 0x030800B2
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, 0, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030400A1
  #define PyMem_RawMalloc(n)           PyMem_Malloc(n)
  #define PyMem_RawRealloc(p, n)       PyMem_Realloc(p, n)
  #define PyMem_RawFree(p)             PyMem_Free(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #if defined(PyUnicode_IS_READY) && defined(PyUnicode_GET_SIZE)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
  #else
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? ((void)(klass), PyMethod_New(func, self)) : __Pyx_NewRef(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__DataGenerator__DatasetGenerator__RootWordDataSetGenerator
#define __PYX_HAVE_API__DataGenerator__DatasetGenerator__RootWordDataSetGenerator
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "DataGenerator/DatasetGenerator/RootWordDataSetGenerator.pyx",
  "Word.pxd",
  "Symbol.pxd",
  "ParseNode.pxd",
  "ParseTree.pxd",
  "FileDescription.pxd",
  "Sentence.pxd",
  "ParserEvaluationScore.pxd",
  "TrieNode.pxd",
  "TxtWord.pxd",
  "Trie.pxd",
  "Dictionary.pxd",
  "TxtDictionary.pxd",
  "LRUCache.pxd",
  "InflectionalGroup.pxd",
  "MorphologicalParse.pxd",
  "State.pxd",
  "FsmParse.pxd",
  "FiniteStateMachine.pxd",
  "MetamorphicParse.pxd",
  "FsmMorphologicalAnalyzer.pxd",
  "Frameset.pxd",
  "FramesetList.pxd",
  "Frame.pxd",
  "FrameNet.pxd",
  "Relation.pxd",
  "Literal.pxd",
  "SemanticRelation.pxd",
  "InterlingualRelation.pxd",
  "Synonym.pxd",
  "SynSet.pxd",
  "WordNet.pxd",
  "AnnotatedSentence.pxd",
  "ParseTreeDrawable.pxd",
  "TreeBank.pxd",
  "TreeBankDrawable.pxd",
  "FeatureSubSet.pxd",
  "Attribute.pxd",
  "Vector.pxd",
  "Instance.pxd",
  "Bootstrap.pxd",
  "DiscreteDistribution.pxd",
  "Matrix.pxd",
  "InstanceList.pxd",
  "DataDefinition.pxd",
  "DataSet.pxd",
  "DataGenerator/InstanceGenerator/InstanceGenerator.pxd",
  "DataGenerator/DatasetGenerator/DataSetGenerator.pxd",
  "DataGenerator/InstanceGenerator/RootWordInstanceGenerator.pxd",
};

/*--- Type declarations ---*/
struct __pyx_obj_10Dictionary_4Word_Word;
struct __pyx_obj_9ParseTree_6Symbol_Symbol;
struct __pyx_obj_9ParseTree_9ParseNode_ParseNode;
struct __pyx_obj_9ParseTree_9ParseTree_ParseTree;
struct __pyx_obj_6Corpus_15FileDescription_FileDescription;
struct __pyx_obj_6Corpus_8Sentence_Sentence;
struct __pyx_obj_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore;
struct __pyx_obj_10Dictionary_4Trie_8TrieNode_TrieNode;
struct __pyx_obj_10Dictionary_7TxtWord_TxtWord;
struct __pyx_obj_10Dictionary_4Trie_4Trie_Trie;
struct __pyx_obj_10Dictionary_10Dictionary_Dictionary;
struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary;
struct __pyx_obj_13DataStructure_5Cache_8LRUCache_LRUCache;
struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup;
struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse;
struct __pyx_obj_21MorphologicalAnalysis_5State_State;
struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse;
struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine;
struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse;
struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer;
struct __pyx_obj_8PropBank_8Frameset_Frameset;
struct __pyx_obj_8PropBank_12FramesetList_FramesetList;
struct __pyx_obj_8FrameNet_5Frame_Frame;
struct __pyx_obj_8FrameNet_8FrameNet_FrameNet;
struct __pyx_obj_7WordNet_8Relation_Relation;
struct __pyx_obj_7WordNet_7Literal_Literal;
struct __pyx_obj_7WordNet_16SemanticRelation_SemanticRelation;
struct __pyx_obj_7WordNet_20InterlingualRelation_InterlingualRelation;
struct __pyx_obj_7WordNet_7Synonym_Synonym;
struct __pyx_obj_7WordNet_6SynSet_SynSet;
struct __pyx_obj_7WordNet_7WordNet_WordNet;
struct __pyx_obj_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence;
struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable;
struct __pyx_obj_9ParseTree_8TreeBank_TreeBank;
struct __pyx_obj_13AnnotatedTree_16TreeBankDrawable_TreeBankDrawable;
struct __pyx_obj_14Classification_16FeatureSelection_13FeatureSubSet_FeatureSubSet;
struct __pyx_obj_14Classification_9Attribute_9Attribute_Attribute;
struct __pyx_obj_4Math_6Vector_Vector;
struct __pyx_obj_14Classification_8Instance_8Instance_Instance;
struct __pyx_obj_8Sampling_9Bootstrap_Bootstrap;
struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution;
struct __pyx_obj_4Math_6Matrix_Matrix;
struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList;
struct __pyx_obj_14Classification_7DataSet_14DataDefinition_DataDefinition;
struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet;
struct __pyx_obj_13DataGenerator_17InstanceGenerator_17InstanceGenerator_InstanceGenerator;
struct __pyx_obj_13DataGenerator_16DatasetGenerator_16DataSetGenerator_DataSetGenerator;
struct __pyx_obj_13DataGenerator_17InstanceGenerator_25RootWordInstanceGenerator_RootWordInstanceGenerator;
struct __pyx_opt_args_9ParseTree_9ParseNode_9ParseNode_addChild;

/* "ParseTree/ParseNode.pxd":13
 *     cpdef ParseNode headLeaf(self)
 *     cpdef ParseNode headChild(self)
 *     cpdef addChild(self, ParseNode child, index=*)             # <<<<<<<<<<<<<<
 *     cpdef correctParents(self)
 *     cpdef removeXNodes(self)
 */
struct __pyx_opt_args_9ParseTree_9ParseNode_9ParseNode_addChild {
  int __pyx_n;
  PyObject *index;
};
struct __pyx_opt_args_6Corpus_15FileDescription_15FileDescription_getFileName;
struct __pyx_opt_args_6Corpus_15FileDescription_15FileDescription_getFileNameWithIndex;
struct __pyx_opt_args_6Corpus_15FileDescription_15FileDescription_nextFileExists;
struct __pyx_opt_args_6Corpus_15FileDescription_15FileDescription_previousFileExists;

/* "Corpus/FileDescription.pxd":9
 *     cpdef int getIndex(self)
 *     cpdef str getExtension(self)
 *     cpdef str getFileName(self, thisPath=*, extension=*)             # <<<<<<<<<<<<<<
 *     cpdef str getFileNameWithExtension(self, str extension)
 *     cpdef str getFileNameWithIndex(self, str thisPath, int index, extension=*)
 */
struct __pyx_opt_args_6Corpus_15FileDescription_15FileDescription_getFileName {
  int __pyx_n;
  PyObject *thisPath;
  PyObject *extension;
};

/* "Corpus/FileDescription.pxd":11
 *     cpdef str getFileName(self, thisPath=*, extension=*)
 *     cpdef str getFileNameWithExtension(self, str extension)
 *     cpdef str getFileNameWithIndex(self, str thisPath, int index, extension=*)             # <<<<<<<<<<<<<<
 *     cpdef str getRawFileName(self)
 *     cpdef addToIndex(self, int count)
 */
struct __pyx_opt_args_6Corpus_15FileDescription_15FileDescription_getFileNameWithIndex {
  int __pyx_n;
  PyObject *extension;
};

/* "Corpus/FileDescription.pxd":14
 *     cpdef str getRawFileName(self)
 *     cpdef addToIndex(self, int count)
 *     cpdef nextFileExists(self, int count, thisPath=*)             # <<<<<<<<<<<<<<
 *     cpdef previousFileExists(self, int count, thisPath=*)
 */
struct __pyx_opt_args_6Corpus_15FileDescription_15FileDescription_nextFileExists {
  int __pyx_n;
  PyObject *thisPath;
};

/* "Corpus/FileDescription.pxd":15
 *     cpdef addToIndex(self, int count)
 *     cpdef nextFileExists(self, int count, thisPath=*)
 *     cpdef previousFileExists(self, int count, thisPath=*)             # <<<<<<<<<<<<<<
 */
struct __pyx_opt_args_6Corpus_15FileDescription_15FileDescription_previousFileExists {
  int __pyx_n;
  PyObject *thisPath;
};
struct __pyx_opt_args_10Dictionary_4Trie_8TrieNode_8TrieNode_addWord;

/* "Dictionary/Trie/TrieNode.pxd":9
 *     cdef set __words
 * 
 *     cpdef addWord(self, str word, Word root, int index=*)             # <<<<<<<<<<<<<<
 *     cpdef TrieNode getChild(self, char ch)
 *     cpdef set getWords(self)
 */
struct __pyx_opt_args_10Dictionary_4Trie_8TrieNode_8TrieNode_addWord {
  int __pyx_n;
  int index;
};
struct __pyx_opt_args_21MorphologicalAnalysis_18FiniteStateMachine_18FiniteStateMachine_addTransition;

/* "MorphologicalAnalysis/FiniteStateMachine.pxd":12
 *     cpdef list getStates(self)
 *     cpdef State getState(self, str name)
 *     cpdef addTransition(self, State fromState, State toState, str _with, str withName, toPos=*)             # <<<<<<<<<<<<<<
 *     cpdef list getTransitions(self, State state)
 */
struct __pyx_opt_args_21MorphologicalAnalysis_18FiniteStateMachine_18FiniteStateMachine_addTransition {
  int __pyx_n;
  PyObject *toPos;
};
struct __pyx_opt_args_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_morphologicalAnalysisRoot;

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pxd":34
 *     cpdef bint __parseExists(self, list fsmParse, str surfaceForm)
 *     cpdef list __parseWord(self, list fsmParse, maxLengthOrSurfaceForm)
 *     cpdef list morphologicalAnalysisRoot(self, str surfaceForm, TxtWord root, state=*)             # <<<<<<<<<<<<<<
 *     cpdef list generateAllParses(self, TxtWord root, int maxLength)
 *     cpdef str replaceRootWord(self, FsmParse parse, TxtWord newRoot)
 */
struct __pyx_opt_args_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_morphologicalAnalysisRoot {
  int __pyx_n;
  PyObject *state;
};
struct __pyx_opt_args_8PropBank_8Frameset_8Frameset_addArgument;

/* "PropBank/Frameset.pxd":10
 * 
 *     cpdef bint containsArgument(self, object argumentType)
 *     cpdef addArgument(self, str argumentType, str definition, str function=*)             # <<<<<<<<<<<<<<
 *     cpdef deleteArgument(self, str argumentType, str definition)
 *     cpdef list getFramesetArguments(self)
 */
struct __pyx_opt_args_8PropBank_8Frameset_8Frameset_addArgument {
  int __pyx_n;
  PyObject *function;
};
struct __pyx_opt_args_7WordNet_6SynSet_6SynSet_getDefinition;

/* "WordNet/SynSet.pxd":24
 *     cpdef setDefinition(self, str definition)
 *     cpdef removeDefinition(self, str definition)
 *     cpdef str getDefinition(self, index=*)             # <<<<<<<<<<<<<<
 *     cpdef str representative(self)
 *     cpdef str getLongDefinition(self)
 */
struct __pyx_opt_args_7WordNet_6SynSet_6SynSet_getDefinition {
  int __pyx_n;
  PyObject *index;
};
struct __pyx_opt_args_7WordNet_7WordNet_7WordNet_constructIdiomLiterals;
struct __pyx_opt_args_7WordNet_7WordNet_7WordNet_constructIdiomSynSets;

/* "WordNet/WordNet.pxd":40
 *     cpdef list constructSynSets(self, str word, MorphologicalParse parse, MetamorphicParse metaParse,
 *                          FsmMorphologicalAnalyzer fsm)
 *     cpdef list constructIdiomLiterals(self, FsmMorphologicalAnalyzer fsm, MorphologicalParse morphologicalParse1,             # <<<<<<<<<<<<<<
 *                                MetamorphicParse metaParse1, MorphologicalParse morphologicalParse2,
 *                                MetamorphicParse metaParse2, MorphologicalParse morphologicalParse3 = *,
 */
struct __pyx_opt_args_7WordNet_7WordNet_7WordNet_constructIdiomLiterals {
  int __pyx_n;
  struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *morphologicalParse3;
  struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *metaParse3;
};

/* "WordNet/WordNet.pxd":44
 *                                MetamorphicParse metaParse2, MorphologicalParse morphologicalParse3 = *,
 *                                MetamorphicParse metaParse3 = *)
 *     cpdef list constructIdiomSynSets(self, FsmMorphologicalAnalyzer fsm, MorphologicalParse morphologicalParse1,             # <<<<<<<<<<<<<<
 *                               MetamorphicParse metaParse1, MorphologicalParse morphologicalParse2,
 *                               MetamorphicParse metaParse2, MorphologicalParse morphologicalParse3 = *,
 */
struct __pyx_opt_args_7WordNet_7WordNet_7WordNet_constructIdiomSynSets {
  int __pyx_n;
  struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *morphologicalParse3;
  struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *metaParse3;
};
struct __pyx_opt_args_17AnnotatedSentence_17AnnotatedSentence_17AnnotatedSentence_getUniversalDependencyFormat;

/* "AnnotatedSentence/AnnotatedSentence.pxd":24
 *     cpdef ParserEvaluationScore compareParses(self, AnnotatedSentence sentence)
 *     cpdef save(self)
 *     cpdef str getUniversalDependencyFormat(self, str path=*)             # <<<<<<<<<<<<<<
 *     cpdef list constructLiterals(self, WordNet wordNet, FsmMorphologicalAnalyzer fsm, int wordIndex)
 *     cpdef list constructSynSets(self, WordNet wordNet, FsmMorphologicalAnalyzer fsm, int wordIndex)
 */
struct __pyx_opt_args_17AnnotatedSentence_17AnnotatedSentence_17AnnotatedSentence_getUniversalDependencyFormat {
  int __pyx_n;
  PyObject *path;
};
struct __pyx_opt_args_13AnnotatedTree_17ParseTreeDrawable_17ParseTreeDrawable_generateAnnotatedSentence;

/* "AnnotatedTree/ParseTreeDrawable.pxd":29
 *     cpdef bint layerAll(self, object viewLayerType)
 *     cpdef clearLayer(self, object viewLayerType)
 *     cpdef AnnotatedSentence generateAnnotatedSentence(self, str language=*)             # <<<<<<<<<<<<<<
 *     cpdef ParseTree generateParseTree(self, bint surfaceForm)
 *     cpdef list extractNodesWithVerbs(self, WordNet wordNet)
 */
struct __pyx_opt_args_13AnnotatedTree_17ParseTreeDrawable_17ParseTreeDrawable_generateAnnotatedSentence {
  int __pyx_n;
  PyObject *language;
};

/* "Dictionary/Word.pxd":1
 * cdef class Word:             # <<<<<<<<<<<<<<
 * 
 *     cdef str name
 */
struct __pyx_obj_10Dictionary_4Word_Word {
  PyObject_HEAD
  struct __pyx_vtabstruct_10Dictionary_4Word_Word *__pyx_vtab;
  PyObject *name;
};


/* "ParseTree/Symbol.pxd":4
 * 
 * 
 * cdef class Symbol(Word):             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isVP(self)
 */
struct __pyx_obj_9ParseTree_6Symbol_Symbol {
  struct __pyx_obj_10Dictionary_4Word_Word __pyx_base;
};


/* "ParseTree/ParseNode.pxd":4
 * 
 * 
 * cdef class ParseNode:             # <<<<<<<<<<<<<<
 * 
 *     cdef list children
 */
struct __pyx_obj_9ParseTree_9ParseNode_ParseNode {
  PyObject_HEAD
  struct __pyx_vtabstruct_9ParseTree_9ParseNode_ParseNode *__pyx_vtab;
  PyObject *children;
  struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *parent;
  struct __pyx_obj_9ParseTree_6Symbol_Symbol *data;
};


/* "ParseTree/ParseTree.pxd":4
 * 
 * 
 * cdef class ParseTree:             # <<<<<<<<<<<<<<
 * 
 *     cdef ParseNode root
 */
struct __pyx_obj_9ParseTree_9ParseTree_ParseTree {
  PyObject_HEAD
  struct __pyx_vtabstruct_9ParseTree_9ParseTree_ParseTree *__pyx_vtab;
  struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *root;
  PyObject *name;
};


/* "Corpus/FileDescription.pxd":1
 * cdef class FileDescription:             # <<<<<<<<<<<<<<
 * 
 *     cdef str __path, __extension
 */
struct __pyx_obj_6Corpus_15FileDescription_FileDescription {
  PyObject_HEAD
  struct __pyx_vtabstruct_6Corpus_15FileDescription_FileDescription *__pyx_vtab;
  PyObject *__pyx___path;
  PyObject *__pyx___extension;
  int __pyx___index;
};


/* "Corpus/Sentence.pxd":4
 * 
 * 
 * cdef class Sentence:             # <<<<<<<<<<<<<<
 * 
 *     cdef list words
 */
struct __pyx_obj_6Corpus_8Sentence_Sentence {
  PyObject_HEAD
  struct __pyx_vtabstruct_6Corpus_8Sentence_Sentence *__pyx_vtab;
  PyObject *words;
};


/* "DependencyParser/ParserEvaluationScore.pxd":1
 * cdef class ParserEvaluationScore:             # <<<<<<<<<<<<<<
 * 
 *     cdef float LAS
 */
struct __pyx_obj_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore {
  PyObject_HEAD
  struct __pyx_vtabstruct_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore *__pyx_vtab;
  float LAS;
  float UAS;
  float LS;
  int wordCount;
};


/* "Dictionary/Trie/TrieNode.pxd":4
 * 
 * 
 * cdef class TrieNode:             # <<<<<<<<<<<<<<
 * 
 *     cdef dict __children
 */
struct __pyx_obj_10Dictionary_4Trie_8TrieNode_TrieNode {
  PyObject_HEAD
  struct __pyx_vtabstruct_10Dictionary_4Trie_8TrieNode_TrieNode *__pyx_vtab;
  PyObject *__pyx___children;
  PyObject *__pyx___words;
};


/* "Dictionary/TxtWord.pxd":4
 * 
 * 
 * cdef class TxtWord(Word):             # <<<<<<<<<<<<<<
 * 
 *     cdef list __flags
 */
struct __pyx_obj_10Dictionary_7TxtWord_TxtWord {
  struct __pyx_obj_10Dictionary_4Word_Word __pyx_base;
  PyObject *__pyx___flags;
};


/* "Dictionary/Trie/Trie.pxd":6
 * 
 * 
 * cdef class Trie:             # <<<<<<<<<<<<<<
 * 
 *     cdef TrieNode __rootNode
 */
struct __pyx_obj_10Dictionary_4Trie_4Trie_Trie {
  PyObject_HEAD
  struct __pyx_vtabstruct_10Dictionary_4Trie_4Trie_Trie *__pyx_vtab;
  struct __pyx_obj_10Dictionary_4Trie_8TrieNode_TrieNode *__pyx___rootNode;
};


/* "Dictionary/Dictionary.pxd":4
 * 
 * 
 * cdef class Dictionary:             # <<<<<<<<<<<<<<
 * 
 *     cdef list words
 */
struct __pyx_obj_10Dictionary_10Dictionary_Dictionary {
  PyObject_HEAD
  struct __pyx_vtabstruct_10Dictionary_10Dictionary_Dictionary *__pyx_vtab;
  PyObject *words;
  PyObject *filename;
  PyObject *comparator;
};


/* "Dictionary/TxtDictionary.pxd":7
 * 
 * 
 * cdef class TxtDictionary(Dictionary):             # <<<<<<<<<<<<<<
 * 
 *     cdef dict __misspelledWords
 */
struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary {
  struct __pyx_obj_10Dictionary_10Dictionary_Dictionary __pyx_base;
  PyObject *__pyx___misspelledWords;
};


/* "DataStructure/Cache/LRUCache.pxd":1
 * cdef class LRUCache(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef int __cacheSize
 */
struct __pyx_obj_13DataStructure_5Cache_8LRUCache_LRUCache {
  PyObject_HEAD
  struct __pyx_vtabstruct_13DataStructure_5Cache_8LRUCache_LRUCache *__pyx_vtab;
  int __pyx___cacheSize;
  PyObject *__pyx___map;
};


/* "MorphologicalAnalysis/InflectionalGroup.pxd":1
 * cdef class InflectionalGroup:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __IG
 */
struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_vtab;
  PyObject *__pyx___IG;
};


/* "MorphologicalAnalysis/MorphologicalParse.pxd":7
 * 
 * 
 * cdef class MorphologicalParse:             # <<<<<<<<<<<<<<
 * 
 *     cdef list inflectionalGroups
 */
struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_vtab;
  PyObject *inflectionalGroups;
  struct __pyx_obj_10Dictionary_4Word_Word *root;
};


/* "MorphologicalAnalysis/State.pxd":1
 * cdef class State:             # <<<<<<<<<<<<<<
 * 
 *     cdef bint __startState, __endState
 */
struct __pyx_obj_21MorphologicalAnalysis_5State_State {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_5State_State *__pyx_vtab;
  int __pyx___startState;
  int __pyx___endState;
  PyObject *__pyx___name;
  PyObject *__pyx___pos;
};


/* "MorphologicalAnalysis/FsmParse.pxd":5
 * 
 * 
 * cdef class FsmParse(MorphologicalParse):             # <<<<<<<<<<<<<<
 * 
 *     cdef list __suffixList
 */
struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse {
  struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse __pyx_base;
  PyObject *__pyx___suffixList;
  PyObject *__pyx___formList;
  PyObject *__pyx___transitionList;
  PyObject *__pyx___withList;
  PyObject *__pyx___initialPos;
  PyObject *__pyx___pos;
  PyObject *__pyx___form;
  PyObject *__pyx___verbAgreement;
  PyObject *__pyx___possesiveAgreement;
};


/* "MorphologicalAnalysis/FiniteStateMachine.pxd":4
 * 
 * 
 * cdef class FiniteStateMachine:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __states
 */
struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *__pyx_vtab;
  PyObject *__pyx___states;
  PyObject *__pyx___transitions;
};


/* "MorphologicalAnalysis/MetamorphicParse.pxd":6
 * 
 * 
 * cdef class MetamorphicParse:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __metaMorphemeList
 */
struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *__pyx_vtab;
  PyObject *__pyx___metaMorphemeList;
  struct __pyx_obj_10Dictionary_4Word_Word *__pyx___root;
};


/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pxd":13
 * 
 * 
 * cdef class FsmMorphologicalAnalyzer:             # <<<<<<<<<<<<<<
 * 
 *     cdef Trie __dictionaryTrie
 */
struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_vtab;
  struct __pyx_obj_10Dictionary_4Trie_4Trie_Trie *__pyx___dictionaryTrie;
  struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *__pyx___finiteStateMachine;
  struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *__pyx___dictionary;
  struct __pyx_obj_13DataStructure_5Cache_8LRUCache_LRUCache *__pyx___cache;
  PyObject *__pyx___mostUsedPatterns;
  PyObject *__pyx___parsedSurfaceForms;
};


/* "PropBank/Frameset.pxd":4
 * 
 * 
 * cdef class Frameset(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef list __framesetArguments
 */
struct __pyx_obj_8PropBank_8Frameset_Frameset {
  PyObject_HEAD
  struct __pyx_vtabstruct_8PropBank_8Frameset_Frameset *__pyx_vtab;
  PyObject *__pyx___framesetArguments;
  PyObject *__pyx___id;
};


/* "PropBank/FramesetList.pxd":4
 * 
 * 
 * cdef class FramesetList(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef list __frames
 */
struct __pyx_obj_8PropBank_12FramesetList_FramesetList {
  PyObject_HEAD
  struct __pyx_vtabstruct_8PropBank_12FramesetList_FramesetList *__pyx_vtab;
  PyObject *__pyx___frames;
};


/* "FrameNet/Frame.pxd":1
 * cdef class Frame:             # <<<<<<<<<<<<<<
 * 
 *     cdef str name
 */
struct __pyx_obj_8FrameNet_5Frame_Frame {
  PyObject_HEAD
  struct __pyx_vtabstruct_8FrameNet_5Frame_Frame *__pyx_vtab;
  PyObject *name;
  PyObject *lexicalUnits;
  PyObject *frameElements;
};


/* "FrameNet/FrameNet.pxd":4
 * 
 * 
 * cdef class FrameNet:             # <<<<<<<<<<<<<<
 * 
 *     cdef list frames
 */
struct __pyx_obj_8FrameNet_8FrameNet_FrameNet {
  PyObject_HEAD
  struct __pyx_vtabstruct_8FrameNet_8FrameNet_FrameNet *__pyx_vtab;
  PyObject *frames;
};


/* "WordNet/Relation.pxd":1
 * cdef class Relation:             # <<<<<<<<<<<<<<
 * 
 *     cdef str name
 */
struct __pyx_obj_7WordNet_8Relation_Relation {
  PyObject_HEAD
  struct __pyx_vtabstruct_7WordNet_8Relation_Relation *__pyx_vtab;
  PyObject *name;
};


/* "WordNet/Literal.pxd":4
 * 
 * 
 * cdef class Literal:             # <<<<<<<<<<<<<<
 * 
 *     cdef str name
 */
struct __pyx_obj_7WordNet_7Literal_Literal {
  PyObject_HEAD
  struct __pyx_vtabstruct_7WordNet_7Literal_Literal *__pyx_vtab;
  PyObject *name;
  int sense;
  PyObject *synSetId;
  PyObject *origin;
  PyObject *relations;
};


/* "WordNet/SemanticRelation.pxd":4
 * 
 * 
 * cdef class SemanticRelation(Relation):             # <<<<<<<<<<<<<<
 * 
 *     cdef object __relationType
 */
struct __pyx_obj_7WordNet_16SemanticRelation_SemanticRelation {
  struct __pyx_obj_7WordNet_8Relation_Relation __pyx_base;
  PyObject *__pyx___relationType;
  int __pyx___toIndex;
};


/* "WordNet/InterlingualRelation.pxd":4
 * 
 * 
 * cdef class InterlingualRelation(Relation):             # <<<<<<<<<<<<<<
 * 
 *     cdef object __dependencyType
 */
struct __pyx_obj_7WordNet_20InterlingualRelation_InterlingualRelation {
  struct __pyx_obj_7WordNet_8Relation_Relation __pyx_base;
  PyObject *__pyx___dependencyType;
};


/* "WordNet/Synonym.pxd":4
 * 
 * 
 * cdef class Synonym:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __literals
 */
struct __pyx_obj_7WordNet_7Synonym_Synonym {
  PyObject_HEAD
  struct __pyx_vtabstruct_7WordNet_7Synonym_Synonym *__pyx_vtab;
  PyObject *__pyx___literals;
};


/* "WordNet/SynSet.pxd":8
 * 
 * 
 * cdef class SynSet:             # <<<<<<<<<<<<<<
 * 
 *     cdef str __id
 */
struct __pyx_obj_7WordNet_6SynSet_SynSet {
  PyObject_HEAD
  struct __pyx_vtabstruct_7WordNet_6SynSet_SynSet *__pyx_vtab;
  PyObject *__pyx___id;
  PyObject *__pyx___pos;
  PyObject *__pyx___definition;
  PyObject *__pyx___example;
  struct __pyx_obj_7WordNet_7Synonym_Synonym *__pyx___synonym;
  PyObject *__pyx___relations;
  PyObject *__pyx___note;
  PyObject *__pyx___wikiPage;
  int __pyx___bcs;
};


/* "WordNet/WordNet.pxd":10
 * 
 * 
 * cdef class WordNet:             # <<<<<<<<<<<<<<
 * 
 *     cdef object __synSetList
 */
struct __pyx_obj_7WordNet_7WordNet_WordNet {
  PyObject_HEAD
  struct __pyx_vtabstruct_7WordNet_7WordNet_WordNet *__pyx_vtab;
  PyObject *__pyx___synSetList;
  PyObject *__pyx___literalList;
  PyObject *__pyx___exceptionList;
  PyObject *__pyx___interlingualList;
};


/* "AnnotatedSentence/AnnotatedSentence.pxd":9
 * 
 * 
 * cdef class AnnotatedSentence(Sentence):             # <<<<<<<<<<<<<<
 * 
 *     cdef str __fileName
 */
struct __pyx_obj_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence {
  struct __pyx_obj_6Corpus_8Sentence_Sentence __pyx_base;
  PyObject *__pyx___fileName;
};


/* "AnnotatedTree/ParseTreeDrawable.pxd":8
 * 
 * 
 * cdef class ParseTreeDrawable(ParseTree):             # <<<<<<<<<<<<<<
 * 
 *     cdef str __name
 */
struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable {
  struct __pyx_obj_9ParseTree_9ParseTree_ParseTree __pyx_base;
  PyObject *__pyx___name;
  struct __pyx_obj_6Corpus_15FileDescription_FileDescription *__pyx___fileDescription;
};


/* "ParseTree/TreeBank.pxd":4
 * 
 * 
 * cdef class TreeBank:             # <<<<<<<<<<<<<<
 * 
 *     cdef list parseTrees
 */
struct __pyx_obj_9ParseTree_8TreeBank_TreeBank {
  PyObject_HEAD
  struct __pyx_vtabstruct_9ParseTree_8TreeBank_TreeBank *__pyx_vtab;
  PyObject *parseTrees;
};


/* "AnnotatedTree/TreeBankDrawable.pxd":5
 * 
 * 
 * cdef class TreeBankDrawable(TreeBank):             # <<<<<<<<<<<<<<
 * 
 *     cpdef list getParseTrees(self)
 */
struct __pyx_obj_13AnnotatedTree_16TreeBankDrawable_TreeBankDrawable {
  struct __pyx_obj_9ParseTree_8TreeBank_TreeBank __pyx_base;
};


/* "Classification/FeatureSelection/FeatureSubSet.pxd":1
 * cdef class FeatureSubSet(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef list __indexList
 */
struct __pyx_obj_14Classification_16FeatureSelection_13FeatureSubSet_FeatureSubSet {
  PyObject_HEAD
  struct __pyx_vtabstruct_14Classification_16FeatureSelection_13FeatureSubSet_FeatureSubSet *__pyx_vtab;
  PyObject *__pyx___indexList;
};


/* "Classification/Attribute/Attribute.pxd":1
 * cdef class Attribute(object):             # <<<<<<<<<<<<<<
 * 
 *     cpdef int continuousAttributeSize(self)
 */
struct __pyx_obj_14Classification_9Attribute_9Attribute_Attribute {
  PyObject_HEAD
  struct __pyx_vtabstruct_14Classification_9Attribute_9Attribute_Attribute *__pyx_vtab;
};


/* "Math/Vector.pxd":1
 * cdef class Vector(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef int __size
 */
struct __pyx_obj_4Math_6Vector_Vector {
  PyObject_HEAD
  struct __pyx_vtabstruct_4Math_6Vector_Vector *__pyx_vtab;
  int __pyx___size;
  PyObject *__pyx___values;
};


/* "Classification/Instance/Instance.pxd":6
 * 
 * 
 * cdef class Instance(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef str __classLabel
 */
struct __pyx_obj_14Classification_8Instance_8Instance_Instance {
  PyObject_HEAD
  struct __pyx_vtabstruct_14Classification_8Instance_8Instance_Instance *__pyx_vtab;
  PyObject *__pyx___classLabel;
  PyObject *__pyx___attributes;
};


/* "Sampling/Bootstrap.pxd":1
 * cdef class Bootstrap:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __instanceList
 */
struct __pyx_obj_8Sampling_9Bootstrap_Bootstrap {
  PyObject_HEAD
  struct __pyx_vtabstruct_8Sampling_9Bootstrap_Bootstrap *__pyx_vtab;
  PyObject *__pyx___instanceList;
};


/* "Math/DiscreteDistribution.pxd":1
 * cdef class DiscreteDistribution(dict):             # <<<<<<<<<<<<<<
 * 
 *     cdef double __sum
 */
struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution {
  PyDictObject __pyx_base;
  struct __pyx_vtabstruct_4Math_20DiscreteDistribution_DiscreteDistribution *__pyx_vtab;
  double __pyx___sum;
};


/* "Math/Matrix.pxd":4
 * 
 * 
 * cdef class Matrix(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef int __row, __col
 */
struct __pyx_obj_4Math_6Matrix_Matrix {
  PyObject_HEAD
  struct __pyx_vtabstruct_4Math_6Matrix_Matrix *__pyx_vtab;
  int __pyx___row;
  int __pyx___col;
  PyObject *__pyx___values;
};


/* "Classification/InstanceList/InstanceList.pxd":9
 * 
 * 
 * cdef class InstanceList(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef list list
 */
struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList {
  PyObject_HEAD
  struct __pyx_vtabstruct_14Classification_12InstanceList_12InstanceList_InstanceList *__pyx_vtab;
  PyObject *list;
};


/* "Classification/DataSet/DataDefinition.pxd":4
 * 
 * 
 * cdef class DataDefinition(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef list __attributeTypes
 */
struct __pyx_obj_14Classification_7DataSet_14DataDefinition_DataDefinition {
  PyObject_HEAD
  struct __pyx_vtabstruct_14Classification_7DataSet_14DataDefinition_DataDefinition *__pyx_vtab;
  PyObject *__pyx___attributeTypes;
};


/* "Classification/DataSet/DataSet.pxd":7
 * 
 * 
 * cdef class DataSet(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef InstanceList __instances
 */
struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet {
  PyObject_HEAD
  struct __pyx_vtabstruct_14Classification_7DataSet_7DataSet_DataSet *__pyx_vtab;
  struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *__pyx___instances;
  struct __pyx_obj_14Classification_7DataSet_14DataDefinition_DataDefinition *__pyx___definition;
};


/* "DataGenerator/InstanceGenerator/InstanceGenerator.pxd":5
 * 
 * 
 * cdef class InstanceGenerator:             # <<<<<<<<<<<<<<
 * 
 *     cdef int windowSize
 */
struct __pyx_obj_13DataGenerator_17InstanceGenerator_17InstanceGenerator_InstanceGenerator {
  PyObject_HEAD
  struct __pyx_vtabstruct_13DataGenerator_17InstanceGenerator_17InstanceGenerator_InstanceGenerator *__pyx_vtab;
  int windowSize;
};


/* "DataGenerator/DatasetGenerator/DataSetGenerator.pxd":7
 * 
 * 
 * cdef class DataSetGenerator:             # <<<<<<<<<<<<<<
 * 
 *     cdef TreeBankDrawable __treeBank
 */
struct __pyx_obj_13DataGenerator_16DatasetGenerator_16DataSetGenerator_DataSetGenerator {
  PyObject_HEAD
  struct __pyx_vtabstruct_13DataGenerator_16DatasetGenerator_16DataSetGenerator_DataSetGenerator *__pyx_vtab;
  struct __pyx_obj_13AnnotatedTree_16TreeBankDrawable_TreeBankDrawable *__pyx___treeBank;
  struct __pyx_obj_13DataGenerator_17InstanceGenerator_17InstanceGenerator_InstanceGenerator *instanceGenerator;
};


/* "DataGenerator/InstanceGenerator/RootWordInstanceGenerator.pxd":6
 * 
 * 
 * cdef class RootWordInstanceGenerator(InstanceGenerator):             # <<<<<<<<<<<<<<
 * 
 *     cpdef addAttributesForPreviousWords(self, Instance current, Sentence sentence, int wordIndex)
 */
struct __pyx_obj_13DataGenerator_17InstanceGenerator_25RootWordInstanceGenerator_RootWordInstanceGenerator {
  struct __pyx_obj_13DataGenerator_17InstanceGenerator_17InstanceGenerator_InstanceGenerator __pyx_base;
};



/* "Dictionary/Word.pxd":1
 * cdef class Word:             # <<<<<<<<<<<<<<
 * 
 *     cdef str name
 */

struct __pyx_vtabstruct_10Dictionary_4Word_Word {
  int (*charCount)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  PyObject *(*getName)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  PyObject *(*setName)(struct __pyx_obj_10Dictionary_4Word_Word *, PyObject *, int __pyx_skip_dispatch);
  int (*isPunctuation)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  PyObject *(*toCharacters)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_10Dictionary_4Word_Word *__pyx_vtabptr_10Dictionary_4Word_Word;


/* "ParseTree/Symbol.pxd":4
 * 
 * 
 * cdef class Symbol(Word):             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isVP(self)
 */

struct __pyx_vtabstruct_9ParseTree_6Symbol_Symbol {
  struct __pyx_vtabstruct_10Dictionary_4Word_Word __pyx_base;
  int (*isVP)(struct __pyx_obj_9ParseTree_6Symbol_Symbol *, int __pyx_skip_dispatch);
  int (*isTerminal)(struct __pyx_obj_9ParseTree_6Symbol_Symbol *, int __pyx_skip_dispatch);
  int (*isChunkLabel)(struct __pyx_obj_9ParseTree_6Symbol_Symbol *, int __pyx_skip_dispatch);
  struct __pyx_obj_9ParseTree_6Symbol_Symbol *(*trimSymbol)(struct __pyx_obj_9ParseTree_6Symbol_Symbol *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_9ParseTree_6Symbol_Symbol *__pyx_vtabptr_9ParseTree_6Symbol_Symbol;


/* "ParseTree/ParseNode.pxd":4
 * 
 * 
 * cdef class ParseNode:             # <<<<<<<<<<<<<<
 * 
 *     cdef list children
 */

struct __pyx_vtabstruct_9ParseTree_9ParseNode_ParseNode {
  struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *(*__pyx___searchHeadChild)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, PyObject *, PyObject *, int, int __pyx_skip_dispatch);
  struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *(*headLeaf)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *(*headChild)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  PyObject *(*addChild)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch, struct __pyx_opt_args_9ParseTree_9ParseNode_9ParseNode_addChild *__pyx_optional_args);
  PyObject *(*correctParents)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  PyObject *(*removeXNodes)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  PyObject *(*setChild)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int, struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  PyObject *(*removeChild)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  int (*leafCount)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  int (*nodeCount)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  int (*nodeCountWithMultipleChildren)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  int (*numberOfChildren)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *(*getChild)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int, int __pyx_skip_dispatch);
  struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *(*firstChild)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *(*lastChild)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  int (*isLastChild)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  int (*getChildIndex)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  int (*isDescendant)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *(*previousSibling)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *(*nextSibling)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *(*getParent)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  struct __pyx_obj_9ParseTree_6Symbol_Symbol *(*getData)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  PyObject *(*setData)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, struct __pyx_obj_9ParseTree_6Symbol_Symbol *, int __pyx_skip_dispatch);
  int (*wordCount)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int, int __pyx_skip_dispatch);
  int (*isLeaf)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  int (*isDummyNode)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  PyObject *(*moveLeft)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  PyObject *(*moveRight)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  PyObject *(*ancestorString)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  PyObject *(*constituentSpanList)(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_9ParseTree_9ParseNode_ParseNode *__pyx_vtabptr_9ParseTree_9ParseNode_ParseNode;


/* "ParseTree/ParseTree.pxd":4
 * 
 * 
 * cdef class ParseTree:             # <<<<<<<<<<<<<<
 * 
 *     cdef ParseNode root
 */

struct __pyx_vtabstruct_9ParseTree_9ParseTree_ParseTree {
  struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *(*nextLeafNode)(struct __pyx_obj_9ParseTree_9ParseTree_ParseTree *, struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *(*previousLeafNode)(struct __pyx_obj_9ParseTree_9ParseTree_ParseTree *, struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  int (*nodeCountWithMultipleChildren)(struct __pyx_obj_9ParseTree_9ParseTree_ParseTree *, int __pyx_skip_dispatch);
  int (*nodeCount)(struct __pyx_obj_9ParseTree_9ParseTree_ParseTree *, int __pyx_skip_dispatch);
  int (*leafCount)(struct __pyx_obj_9ParseTree_9ParseTree_ParseTree *, int __pyx_skip_dispatch);
  PyObject *(*setName)(struct __pyx_obj_9ParseTree_9ParseTree_ParseTree *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getName)(struct __pyx_obj_9ParseTree_9ParseTree_ParseTree *, int __pyx_skip_dispatch);
  int (*isFullSentence)(struct __pyx_obj_9ParseTree_9ParseTree_ParseTree *, int __pyx_skip_dispatch);
  PyObject *(*save)(struct __pyx_obj_9ParseTree_9ParseTree_ParseTree *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*correctParents)(struct __pyx_obj_9ParseTree_9ParseTree_ParseTree *, int __pyx_skip_dispatch);
  PyObject *(*removeXNodes)(struct __pyx_obj_9ParseTree_9ParseTree_ParseTree *, int __pyx_skip_dispatch);
  struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *(*getRoot)(struct __pyx_obj_9ParseTree_9ParseTree_ParseTree *, int __pyx_skip_dispatch);
  int (*wordCount)(struct __pyx_obj_9ParseTree_9ParseTree_ParseTree *, int, int __pyx_skip_dispatch);
  PyObject *(*constituentSpanList)(struct __pyx_obj_9ParseTree_9ParseTree_ParseTree *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_9ParseTree_9ParseTree_ParseTree *__pyx_vtabptr_9ParseTree_9ParseTree_ParseTree;


/* "Corpus/FileDescription.pxd":1
 * cdef class FileDescription:             # <<<<<<<<<<<<<<
 * 
 *     cdef str __path, __extension
 */

struct __pyx_vtabstruct_6Corpus_15FileDescription_FileDescription {
  PyObject *(*getPath)(struct __pyx_obj_6Corpus_15FileDescription_FileDescription *, int __pyx_skip_dispatch);
  int (*getIndex)(struct __pyx_obj_6Corpus_15FileDescription_FileDescription *, int __pyx_skip_dispatch);
  PyObject *(*getExtension)(struct __pyx_obj_6Corpus_15FileDescription_FileDescription *, int __pyx_skip_dispatch);
  PyObject *(*getFileName)(struct __pyx_obj_6Corpus_15FileDescription_FileDescription *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Corpus_15FileDescription_15FileDescription_getFileName *__pyx_optional_args);
  PyObject *(*getFileNameWithExtension)(struct __pyx_obj_6Corpus_15FileDescription_FileDescription *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getFileNameWithIndex)(struct __pyx_obj_6Corpus_15FileDescription_FileDescription *, PyObject *, int, int __pyx_skip_dispatch, struct __pyx_opt_args_6Corpus_15FileDescription_15FileDescription_getFileNameWithIndex *__pyx_optional_args);
  PyObject *(*getRawFileName)(struct __pyx_obj_6Corpus_15FileDescription_FileDescription *, int __pyx_skip_dispatch);
  PyObject *(*addToIndex)(struct __pyx_obj_6Corpus_15FileDescription_FileDescription *, int, int __pyx_skip_dispatch);
  PyObject *(*nextFileExists)(struct __pyx_obj_6Corpus_15FileDescription_FileDescription *, int, int __pyx_skip_dispatch, struct __pyx_opt_args_6Corpus_15FileDescription_15FileDescription_nextFileExists *__pyx_optional_args);
  PyObject *(*previousFileExists)(struct __pyx_obj_6Corpus_15FileDescription_FileDescription *, int, int __pyx_skip_dispatch, struct __pyx_opt_args_6Corpus_15FileDescription_15FileDescription_previousFileExists *__pyx_optional_args);
};
static struct __pyx_vtabstruct_6Corpus_15FileDescription_FileDescription *__pyx_vtabptr_6Corpus_15FileDescription_FileDescription;


/* "Corpus/Sentence.pxd":4
 * 
 * 
 * cdef class Sentence:             # <<<<<<<<<<<<<<
 * 
 *     cdef list words
 */

struct __pyx_vtabstruct_6Corpus_8Sentence_Sentence {
  struct __pyx_obj_10Dictionary_4Word_Word *(*getWord)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, int, int __pyx_skip_dispatch);
  PyObject *(*getWords)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, int __pyx_skip_dispatch);
  PyObject *(*getStrings)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, int __pyx_skip_dispatch);
  int (*getIndex)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  int (*wordCount)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, int __pyx_skip_dispatch);
  PyObject *(*addWord)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  int (*charCount)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, int __pyx_skip_dispatch);
  PyObject *(*insertWord)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, int, struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  PyObject *(*replaceWord)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, int, struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  int (*safeIndex)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, int, int __pyx_skip_dispatch);
  PyObject *(*toString)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, int __pyx_skip_dispatch);
  PyObject *(*writeToFile)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6Corpus_8Sentence_Sentence *__pyx_vtabptr_6Corpus_8Sentence_Sentence;


/* "DependencyParser/ParserEvaluationScore.pxd":1
 * cdef class ParserEvaluationScore:             # <<<<<<<<<<<<<<
 * 
 *     cdef float LAS
 */

struct __pyx_vtabstruct_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore {
  float (*getLS)(struct __pyx_obj_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore *, int __pyx_skip_dispatch);
  float (*getLAS)(struct __pyx_obj_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore *, int __pyx_skip_dispatch);
  float (*getUAS)(struct __pyx_obj_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore *, int __pyx_skip_dispatch);
  int (*getWordCount)(struct __pyx_obj_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore *, int __pyx_skip_dispatch);
  PyObject *(*add)(struct __pyx_obj_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore *, struct __pyx_obj_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore *__pyx_vtabptr_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore;


/* "Dictionary/Trie/TrieNode.pxd":4
 * 
 * 
 * cdef class TrieNode:             # <<<<<<<<<<<<<<
 * 
 *     cdef dict __children
 */

struct __pyx_vtabstruct_10Dictionary_4Trie_8TrieNode_TrieNode {
  PyObject *(*addWord)(struct __pyx_obj_10Dictionary_4Trie_8TrieNode_TrieNode *, PyObject *, struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch, struct __pyx_opt_args_10Dictionary_4Trie_8TrieNode_8TrieNode_addWord *__pyx_optional_args);
  struct __pyx_obj_10Dictionary_4Trie_8TrieNode_TrieNode *(*getChild)(struct __pyx_obj_10Dictionary_4Trie_8TrieNode_TrieNode *, char, int __pyx_skip_dispatch);
  PyObject *(*getWords)(struct __pyx_obj_10Dictionary_4Trie_8TrieNode_TrieNode *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_10Dictionary_4Trie_8TrieNode_TrieNode *__pyx_vtabptr_10Dictionary_4Trie_8TrieNode_TrieNode;


/* "Dictionary/TxtWord.pxd":4
 * 
 * 
 * cdef class TxtWord(Word):             # <<<<<<<<<<<<<<
 * 
 *     cdef list __flags
 */

struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord {
  struct __pyx_vtabstruct_10Dictionary_4Word_Word __pyx_base;
  PyObject *(*addFlag)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*removeFlag)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*verbType)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*samePos)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isNominal)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPassive)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isAbbreviation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isInterjection)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isDuplicate)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isHeader)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isAdjective)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPureAdjective)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPronoun)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isQuestion)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isVerb)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPortmanteau)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isDeterminer)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isConjunction)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isAdverb)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPostP)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPortmanteauEndingWithSI)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPortmanteauFacedVowelEllipsis)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPortmanteauFacedSoftening)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isSuffix)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isProperNoun)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPlural)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isNumeral)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isReal)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isFraction)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isTime)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isDate)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPercent)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isRange)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isOrdinal)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*notObeysVowelHarmonyDuringAgglutination)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*obeysAndNotObeysVowelHarmonyDuringAgglutination)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*rootSoftenDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*rootSoftenAndNotSoftenDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*verbSoftenDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*nounSoftenDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*endingKChangesIntoG)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isExceptional)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*duplicatesDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*duplicatesAndNotDuplicatesDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*lastIdropsDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*lastIDropsAndNotDropDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*takesRelativeSuffixKi)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*takesRelativeSuffixKu)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*consonantSMayInsertedDuringPossesiveSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*lastIdropsDuringPassiveSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*vowelAChangesToIDuringYSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*vowelEChangesToIDuringYSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*takesSuffixIRAsAorist)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*takesSuffixDIRAsFactitive)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*showsSuRegularities)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*containsFlag)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *__pyx_vtabptr_10Dictionary_7TxtWord_TxtWord;


/* "Dictionary/Trie/Trie.pxd":6
 * 
 * 
 * cdef class Trie:             # <<<<<<<<<<<<<<
 * 
 *     cdef TrieNode __rootNode
 */

struct __pyx_vtabstruct_10Dictionary_4Trie_4Trie_Trie {
  PyObject *(*addWord)(struct __pyx_obj_10Dictionary_4Trie_4Trie_Trie *, PyObject *, struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  PyObject *(*getWordsWithPrefix)(struct __pyx_obj_10Dictionary_4Trie_4Trie_Trie *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *(*getCompundWordStartingWith)(struct __pyx_obj_10Dictionary_4Trie_4Trie_Trie *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_10Dictionary_4Trie_4Trie_Trie *__pyx_vtabptr_10Dictionary_4Trie_4Trie_Trie;


/* "Dictionary/Dictionary.pxd":4
 * 
 * 
 * cdef class Dictionary:             # <<<<<<<<<<<<<<
 * 
 *     cdef list words
 */

struct __pyx_vtabstruct_10Dictionary_10Dictionary_Dictionary {
  struct __pyx_obj_10Dictionary_4Word_Word *(*getWord)(struct __pyx_obj_10Dictionary_10Dictionary_Dictionary *, PyObject *, int __pyx_skip_dispatch);
  int (*getWordIndex)(struct __pyx_obj_10Dictionary_10Dictionary_Dictionary *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*removeWord)(struct __pyx_obj_10Dictionary_10Dictionary_Dictionary *, PyObject *, int __pyx_skip_dispatch);
  int (*size)(struct __pyx_obj_10Dictionary_10Dictionary_Dictionary *, int __pyx_skip_dispatch);
  struct __pyx_obj_10Dictionary_4Word_Word *(*getWordWithIndex)(struct __pyx_obj_10Dictionary_10Dictionary_Dictionary *, int, int __pyx_skip_dispatch);
  int (*longestWordSize)(struct __pyx_obj_10Dictionary_10Dictionary_Dictionary *, int __pyx_skip_dispatch);
  int (*__pyx___getPosition)(struct __pyx_obj_10Dictionary_10Dictionary_Dictionary *, struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  int (*getWordStartingWith)(struct __pyx_obj_10Dictionary_10Dictionary_Dictionary *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_10Dictionary_10Dictionary_Dictionary *__pyx_vtabptr_10Dictionary_10Dictionary_Dictionary;


/* "Dictionary/TxtDictionary.pxd":7
 * 
 * 
 * cdef class TxtDictionary(Dictionary):             # <<<<<<<<<<<<<<
 * 
 *     cdef dict __misspelledWords
 */

struct __pyx_vtabstruct_10Dictionary_13TxtDictionary_TxtDictionary {
  struct __pyx_vtabstruct_10Dictionary_10Dictionary_Dictionary __pyx_base;
  PyObject *(*addNumber)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*addRealNumber)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*addFraction)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*addTime)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  int (*addProperNoun)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  int (*addNoun)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  int (*addVerb)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  int (*addAdjective)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  int (*addAdverb)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  int (*addPronoun)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  int (*addWithFlag)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*mergeDictionary)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___loadFromText)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___loadMisspelledWords)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getCorrectForm)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*saveAsTxt)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___addWordWhenRootSoften)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, struct __pyx_obj_10Dictionary_4Trie_4Trie_Trie *, Py_UNICODE, PyObject *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  struct __pyx_obj_10Dictionary_4Trie_4Trie_Trie *(*prepareTrie)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_10Dictionary_13TxtDictionary_TxtDictionary *__pyx_vtabptr_10Dictionary_13TxtDictionary_TxtDictionary;


/* "DataStructure/Cache/LRUCache.pxd":1
 * cdef class LRUCache(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef int __cacheSize
 */

struct __pyx_vtabstruct_13DataStructure_5Cache_8LRUCache_LRUCache {
  int (*contains)(struct __pyx_obj_13DataStructure_5Cache_8LRUCache_LRUCache *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*get)(struct __pyx_obj_13DataStructure_5Cache_8LRUCache_LRUCache *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*add)(struct __pyx_obj_13DataStructure_5Cache_8LRUCache_LRUCache *, PyObject *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_13DataStructure_5Cache_8LRUCache_LRUCache *__pyx_vtabptr_13DataStructure_5Cache_8LRUCache_LRUCache;


/* "MorphologicalAnalysis/InflectionalGroup.pxd":1
 * cdef class InflectionalGroup:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __IG
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup {
  PyObject *(*getTag)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int, int __pyx_skip_dispatch);
  int (*size)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int __pyx_skip_dispatch);
  PyObject *(*containsCase)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int __pyx_skip_dispatch);
  int (*containsPlural)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int __pyx_skip_dispatch);
  int (*containsTag)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, PyObject *, int __pyx_skip_dispatch);
  int (*containsPossessive)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_vtabptr_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup;


/* "MorphologicalAnalysis/MorphologicalParse.pxd":7
 * 
 * 
 * cdef class MorphologicalParse:             # <<<<<<<<<<<<<<
 * 
 *     cdef list inflectionalGroups
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse {
  struct __pyx_obj_10Dictionary_4Word_Word *(*getWord)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getTransitionList)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getInflectionalGroupString)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*getInflectionalGroup)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*getLastInflectionalGroup)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getTag)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int, int __pyx_skip_dispatch);
  int (*tagSize)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*size)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*firstInflectionalGroup)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*lastInflectionalGroup)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_10Dictionary_4Word_Word *(*getWordWithPos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getPos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getRootPos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*lastIGContainsCase)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*lastIGContainsTag)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, PyObject *, int __pyx_skip_dispatch);
  int (*lastIGContainsPossessive)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isCapitalWord)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isNoun)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isVerb)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isRootVerb)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isAdjective)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isProperNoun)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isPunctuation)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isCardinal)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isOrdinal)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isReal)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isNumber)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isTime)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isDate)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isHashTag)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isEmail)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isPercent)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isFraction)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isRange)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isPlural)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isAuxiliary)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*containsTag)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getTreePos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getPronType)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getNumType)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getReflex)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getNumber)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getCase)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getDefinite)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getDegree)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getPolarity)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getPerson)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getVoice)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getAspect)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getTense)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getMood)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getVerbForm)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getUniversalDependencyFeatures)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getUniversalDependencyPos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_vtabptr_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse;


/* "MorphologicalAnalysis/State.pxd":1
 * cdef class State:             # <<<<<<<<<<<<<<
 * 
 *     cdef bint __startState, __endState
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_5State_State {
  PyObject *(*getName)(struct __pyx_obj_21MorphologicalAnalysis_5State_State *, int __pyx_skip_dispatch);
  PyObject *(*getPos)(struct __pyx_obj_21MorphologicalAnalysis_5State_State *, int __pyx_skip_dispatch);
  int (*isEndState)(struct __pyx_obj_21MorphologicalAnalysis_5State_State *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_5State_State *__pyx_vtabptr_21MorphologicalAnalysis_5State_State;


/* "MorphologicalAnalysis/FsmParse.pxd":5
 * 
 * 
 * cdef class FsmParse(MorphologicalParse):             # <<<<<<<<<<<<<<
 * 
 *     cdef list __suffixList
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse {
  struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse __pyx_base;
  PyObject *(*constructInflectionalGroups)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*getVerbAgreement)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*getPossesiveAgreement)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*setAgreement)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getLastLemmaWithTag)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getLastLemma)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*addSuffix)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, struct __pyx_obj_21MorphologicalAnalysis_5State_State *, PyObject *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getSurfaceForm)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_5State_State *(*getStartState)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*getFinalPos)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*getInitialPos)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*setForm)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_5State_State *(*getFinalSuffix)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*headerTransition)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*pronounTransition)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*transitionList)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*suffixList)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*withList)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*getWithList)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_vtabptr_21MorphologicalAnalysis_8FsmParse_FsmParse;


/* "MorphologicalAnalysis/FiniteStateMachine.pxd":4
 * 
 * 
 * cdef class FiniteStateMachine:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __states
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine {
  int (*isValidTransition)(struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getStates)(struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_5State_State *(*getState)(struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*addTransition)(struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *, struct __pyx_obj_21MorphologicalAnalysis_5State_State *, struct __pyx_obj_21MorphologicalAnalysis_5State_State *, PyObject *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_21MorphologicalAnalysis_18FiniteStateMachine_18FiniteStateMachine_addTransition *__pyx_optional_args);
  PyObject *(*getTransitions)(struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *, struct __pyx_obj_21MorphologicalAnalysis_5State_State *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *__pyx_vtabptr_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine;


/* "MorphologicalAnalysis/MetamorphicParse.pxd":6
 * 
 * 
 * cdef class MetamorphicParse:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __metaMorphemeList
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse {
  PyObject *(*getMetaMorphemeTag)(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_10Dictionary_4Word_Word *(*getWord)(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, int __pyx_skip_dispatch);
  PyObject *(*getMetaMorphemeTagForParse)(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, PyObject *, int __pyx_skip_dispatch);
  int (*size)(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, int __pyx_skip_dispatch);
  PyObject *(*addMetaMorphemeList)(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*removeMetaMorphemeFromIndex)(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, int, int __pyx_skip_dispatch);
  PyObject *(*getMetaMorpheme)(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, int, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *__pyx_vtabptr_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse;


/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pxd":13
 * 
 * 
 * cdef class FsmMorphologicalAnalyzer:             # <<<<<<<<<<<<<<
 * 
 *     cdef Trie __dictionaryTrie
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer {
  PyObject *(*addParsedSurfaceForms)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getPossibleWords)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *(*getDictionary)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *(*getFiniteStateMachine)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, int __pyx_skip_dispatch);
  int (*__pyx___isPossibleSubstring)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, PyObject *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___initializeParseList)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int, int __pyx_skip_dispatch);
  PyObject *(*__pyx___initializeParseListFromRoot)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int, int __pyx_skip_dispatch);
  PyObject *(*__pyx___initializeParseListFromSurfaceForm)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int, int __pyx_skip_dispatch);
  PyObject *(*__pyx___addNewParsesFromCurrentParse)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, PyObject *, PyObject *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*__pyx___parseExists)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___parseWord)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*morphologicalAnalysisRoot)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch, struct __pyx_opt_args_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_morphologicalAnalysisRoot *__pyx_optional_args);
  PyObject *(*generateAllParses)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int, int __pyx_skip_dispatch);
  PyObject *(*replaceRootWord)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  struct __pyx_obj_6Corpus_8Sentence_Sentence *(*replaceWord)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, struct __pyx_obj_6Corpus_8Sentence_Sentence *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  int (*__pyx___analysisExists)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, int, int __pyx_skip_dispatch);
  PyObject *(*__pyx___analysis)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int, int __pyx_skip_dispatch);
  int (*patternMatches)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  int (*isProperNoun)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*morphologicalAnalysis)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*robustMorphologicalAnalysis)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  int (*__pyx___isInteger)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  int (*__pyx___isDouble)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  int (*__pyx___isNumber)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  int (*__pyx___isPercent)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  int (*__pyx___isTime)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  int (*__pyx___isRange)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  int (*__pyx___isDate)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___toLower)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  int (*morphologicalAnalysisExists)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_vtabptr_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer;


/* "PropBank/Frameset.pxd":4
 * 
 * 
 * cdef class Frameset(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef list __framesetArguments
 */

struct __pyx_vtabstruct_8PropBank_8Frameset_Frameset {
  int (*containsArgument)(struct __pyx_obj_8PropBank_8Frameset_Frameset *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*addArgument)(struct __pyx_obj_8PropBank_8Frameset_Frameset *, PyObject *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_8PropBank_8Frameset_8Frameset_addArgument *__pyx_optional_args);
  PyObject *(*deleteArgument)(struct __pyx_obj_8PropBank_8Frameset_Frameset *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getFramesetArguments)(struct __pyx_obj_8PropBank_8Frameset_Frameset *, int __pyx_skip_dispatch);
  PyObject *(*getId)(struct __pyx_obj_8PropBank_8Frameset_Frameset *, int __pyx_skip_dispatch);
  PyObject *(*setId)(struct __pyx_obj_8PropBank_8Frameset_Frameset *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*save)(struct __pyx_obj_8PropBank_8Frameset_Frameset *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_8PropBank_8Frameset_Frameset *__pyx_vtabptr_8PropBank_8Frameset_Frameset;


/* "PropBank/FramesetList.pxd":4
 * 
 * 
 * cdef class FramesetList(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef list __frames
 */

struct __pyx_vtabstruct_8PropBank_12FramesetList_FramesetList {
  PyObject *(*readFromXml)(struct __pyx_obj_8PropBank_12FramesetList_FramesetList *, PyObject *, int __pyx_skip_dispatch);
  int (*frameExists)(struct __pyx_obj_8PropBank_12FramesetList_FramesetList *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_8PropBank_8Frameset_Frameset *(*getFrameSet)(struct __pyx_obj_8PropBank_12FramesetList_FramesetList *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*addFrameset)(struct __pyx_obj_8PropBank_12FramesetList_FramesetList *, struct __pyx_obj_8PropBank_8Frameset_Frameset *, int __pyx_skip_dispatch);
  int (*size)(struct __pyx_obj_8PropBank_12FramesetList_FramesetList *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_8PropBank_12FramesetList_FramesetList *__pyx_vtabptr_8PropBank_12FramesetList_FramesetList;


/* "FrameNet/Frame.pxd":1
 * cdef class Frame:             # <<<<<<<<<<<<<<
 * 
 *     cdef str name
 */

struct __pyx_vtabstruct_8FrameNet_5Frame_Frame {
  PyObject *(*addLexicalUnit)(struct __pyx_obj_8FrameNet_5Frame_Frame *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*addFrameElement)(struct __pyx_obj_8FrameNet_5Frame_Frame *, PyObject *, int __pyx_skip_dispatch);
  int (*lexicalUnitExists)(struct __pyx_obj_8FrameNet_5Frame_Frame *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getLexicalUnit)(struct __pyx_obj_8FrameNet_5Frame_Frame *, int, int __pyx_skip_dispatch);
  PyObject *(*getFrameElement)(struct __pyx_obj_8FrameNet_5Frame_Frame *, int, int __pyx_skip_dispatch);
  int (*lexicalUnitSize)(struct __pyx_obj_8FrameNet_5Frame_Frame *, int __pyx_skip_dispatch);
  int (*frameElementSize)(struct __pyx_obj_8FrameNet_5Frame_Frame *, int __pyx_skip_dispatch);
  PyObject *(*getName)(struct __pyx_obj_8FrameNet_5Frame_Frame *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_8FrameNet_5Frame_Frame *__pyx_vtabptr_8FrameNet_5Frame_Frame;


/* "FrameNet/FrameNet.pxd":4
 * 
 * 
 * cdef class FrameNet:             # <<<<<<<<<<<<<<
 * 
 *     cdef list frames
 */

struct __pyx_vtabstruct_8FrameNet_8FrameNet_FrameNet {
  int (*lexicalUnitExists)(struct __pyx_obj_8FrameNet_8FrameNet_FrameNet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getFrames)(struct __pyx_obj_8FrameNet_8FrameNet_FrameNet *, PyObject *, int __pyx_skip_dispatch);
  int (*size)(struct __pyx_obj_8FrameNet_8FrameNet_FrameNet *, int __pyx_skip_dispatch);
  struct __pyx_obj_8FrameNet_5Frame_Frame *(*getFrame)(struct __pyx_obj_8FrameNet_8FrameNet_FrameNet *, int, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_8FrameNet_8FrameNet_FrameNet *__pyx_vtabptr_8FrameNet_8FrameNet_FrameNet;


/* "WordNet/Relation.pxd":1
 * cdef class Relation:             # <<<<<<<<<<<<<<
 * 
 *     cdef str name
 */

struct __pyx_vtabstruct_7WordNet_8Relation_Relation {
  PyObject *(*getName)(struct __pyx_obj_7WordNet_8Relation_Relation *, int __pyx_skip_dispatch);
  PyObject *(*setName)(struct __pyx_obj_7WordNet_8Relation_Relation *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_7WordNet_8Relation_Relation *__pyx_vtabptr_7WordNet_8Relation_Relation;


/* "WordNet/Literal.pxd":4
 * 
 * 
 * cdef class Literal:             # <<<<<<<<<<<<<<
 * 
 *     cdef str name
 */

struct __pyx_vtabstruct_7WordNet_7Literal_Literal {
  PyObject *(*getSynSetId)(struct __pyx_obj_7WordNet_7Literal_Literal *, int __pyx_skip_dispatch);
  PyObject *(*getName)(struct __pyx_obj_7WordNet_7Literal_Literal *, int __pyx_skip_dispatch);
  int (*getSense)(struct __pyx_obj_7WordNet_7Literal_Literal *, int __pyx_skip_dispatch);
  PyObject *(*getOrigin)(struct __pyx_obj_7WordNet_7Literal_Literal *, int __pyx_skip_dispatch);
  PyObject *(*setOrigin)(struct __pyx_obj_7WordNet_7Literal_Literal *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*setSense)(struct __pyx_obj_7WordNet_7Literal_Literal *, int, int __pyx_skip_dispatch);
  PyObject *(*addRelation)(struct __pyx_obj_7WordNet_7Literal_Literal *, struct __pyx_obj_7WordNet_8Relation_Relation *, int __pyx_skip_dispatch);
  PyObject *(*removeRelation)(struct __pyx_obj_7WordNet_7Literal_Literal *, struct __pyx_obj_7WordNet_8Relation_Relation *, int __pyx_skip_dispatch);
  int (*containsRelation)(struct __pyx_obj_7WordNet_7Literal_Literal *, struct __pyx_obj_7WordNet_8Relation_Relation *, int __pyx_skip_dispatch);
  int (*containsRelationType)(struct __pyx_obj_7WordNet_7Literal_Literal *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_7WordNet_8Relation_Relation *(*getRelation)(struct __pyx_obj_7WordNet_7Literal_Literal *, int, int __pyx_skip_dispatch);
  int (*relationSize)(struct __pyx_obj_7WordNet_7Literal_Literal *, int __pyx_skip_dispatch);
  PyObject *(*setName)(struct __pyx_obj_7WordNet_7Literal_Literal *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*setSynSetId)(struct __pyx_obj_7WordNet_7Literal_Literal *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*saveAsXml)(struct __pyx_obj_7WordNet_7Literal_Literal *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_7WordNet_7Literal_Literal *__pyx_vtabptr_7WordNet_7Literal_Literal;


/* "WordNet/SemanticRelation.pxd":4
 * 
 * 
 * cdef class SemanticRelation(Relation):             # <<<<<<<<<<<<<<
 * 
 *     cdef object __relationType
 */

struct __pyx_vtabstruct_7WordNet_16SemanticRelation_SemanticRelation {
  struct __pyx_vtabstruct_7WordNet_8Relation_Relation __pyx_base;
  int (*toIndex)(struct __pyx_obj_7WordNet_16SemanticRelation_SemanticRelation *, int __pyx_skip_dispatch);
  PyObject *(*getRelationType)(struct __pyx_obj_7WordNet_16SemanticRelation_SemanticRelation *, int __pyx_skip_dispatch);
  PyObject *(*setRelationType)(struct __pyx_obj_7WordNet_16SemanticRelation_SemanticRelation *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getTypeAsString)(struct __pyx_obj_7WordNet_16SemanticRelation_SemanticRelation *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_7WordNet_16SemanticRelation_SemanticRelation *__pyx_vtabptr_7WordNet_16SemanticRelation_SemanticRelation;


/* "WordNet/InterlingualRelation.pxd":4
 * 
 * 
 * cdef class InterlingualRelation(Relation):             # <<<<<<<<<<<<<<
 * 
 *     cdef object __dependencyType
 */

struct __pyx_vtabstruct_7WordNet_20InterlingualRelation_InterlingualRelation {
  struct __pyx_vtabstruct_7WordNet_8Relation_Relation __pyx_base;
  PyObject *(*getType)(struct __pyx_obj_7WordNet_20InterlingualRelation_InterlingualRelation *, int __pyx_skip_dispatch);
  PyObject *(*getTypeAsString)(struct __pyx_obj_7WordNet_20InterlingualRelation_InterlingualRelation *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_7WordNet_20InterlingualRelation_InterlingualRelation *__pyx_vtabptr_7WordNet_20InterlingualRelation_InterlingualRelation;


/* "WordNet/Synonym.pxd":4
 * 
 * 
 * cdef class Synonym:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __literals
 */

struct __pyx_vtabstruct_7WordNet_7Synonym_Synonym {
  PyObject *(*addLiteral)(struct __pyx_obj_7WordNet_7Synonym_Synonym *, struct __pyx_obj_7WordNet_7Literal_Literal *, int __pyx_skip_dispatch);
  PyObject *(*moveFirst)(struct __pyx_obj_7WordNet_7Synonym_Synonym *, struct __pyx_obj_7WordNet_7Literal_Literal *, int __pyx_skip_dispatch);
  struct __pyx_obj_7WordNet_7Literal_Literal *(*getLiteral)(struct __pyx_obj_7WordNet_7Synonym_Synonym *, PyObject *, int __pyx_skip_dispatch);
  int (*literalSize)(struct __pyx_obj_7WordNet_7Synonym_Synonym *, int __pyx_skip_dispatch);
  int (*contains)(struct __pyx_obj_7WordNet_7Synonym_Synonym *, struct __pyx_obj_7WordNet_7Literal_Literal *, int __pyx_skip_dispatch);
  int (*containsLiteral)(struct __pyx_obj_7WordNet_7Synonym_Synonym *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*removeLiteral)(struct __pyx_obj_7WordNet_7Synonym_Synonym *, struct __pyx_obj_7WordNet_7Literal_Literal *, int __pyx_skip_dispatch);
  PyObject *(*saveAsXml)(struct __pyx_obj_7WordNet_7Synonym_Synonym *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_7WordNet_7Synonym_Synonym *__pyx_vtabptr_7WordNet_7Synonym_Synonym;


/* "WordNet/SynSet.pxd":8
 * 
 * 
 * cdef class SynSet:             # <<<<<<<<<<<<<<
 * 
 *     cdef str __id
 */

struct __pyx_vtabstruct_7WordNet_6SynSet_SynSet {
  PyObject *(*getId)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, int __pyx_skip_dispatch);
  PyObject *(*setId)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*setDefinition)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*removeDefinition)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getDefinition)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, int __pyx_skip_dispatch, struct __pyx_opt_args_7WordNet_6SynSet_6SynSet_getDefinition *__pyx_optional_args);
  PyObject *(*representative)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, int __pyx_skip_dispatch);
  PyObject *(*getLongDefinition)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, int __pyx_skip_dispatch);
  PyObject *(*sortDefinitions)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, int __pyx_skip_dispatch);
  int (*numberOfDefinitions)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, int __pyx_skip_dispatch);
  PyObject *(*setExample)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getExample)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, int __pyx_skip_dispatch);
  PyObject *(*setBcs)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, int, int __pyx_skip_dispatch);
  int (*getBcs)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, int __pyx_skip_dispatch);
  PyObject *(*setPos)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getPos)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, int __pyx_skip_dispatch);
  PyObject *(*setNote)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getNote)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, int __pyx_skip_dispatch);
  PyObject *(*setWikiPage)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getWikiPage)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, int __pyx_skip_dispatch);
  PyObject *(*addRelation)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, struct __pyx_obj_7WordNet_8Relation_Relation *, int __pyx_skip_dispatch);
  PyObject *(*removeRelation)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_7WordNet_8Relation_Relation *(*getRelation)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, int, int __pyx_skip_dispatch);
  PyObject *(*getInterlingual)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, int __pyx_skip_dispatch);
  int (*relationSize)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, int __pyx_skip_dispatch);
  PyObject *(*addLiteral)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, struct __pyx_obj_7WordNet_7Literal_Literal *, int __pyx_skip_dispatch);
  struct __pyx_obj_7WordNet_7Synonym_Synonym *(*getSynonym)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, int __pyx_skip_dispatch);
  int (*containsSameLiteral)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, struct __pyx_obj_7WordNet_6SynSet_SynSet *, int __pyx_skip_dispatch);
  int (*containsRelation)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, struct __pyx_obj_7WordNet_8Relation_Relation *, int __pyx_skip_dispatch);
  int (*containsRelationType)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*mergeSynSet)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, struct __pyx_obj_7WordNet_6SynSet_SynSet *, int __pyx_skip_dispatch);
  PyObject *(*saveAsXml)(struct __pyx_obj_7WordNet_6SynSet_SynSet *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_7WordNet_6SynSet_SynSet *__pyx_vtabptr_7WordNet_6SynSet_SynSet;


/* "WordNet/WordNet.pxd":10
 * 
 * 
 * cdef class WordNet:             # <<<<<<<<<<<<<<
 * 
 *     cdef object __synSetList
 */

struct __pyx_vtabstruct_7WordNet_7WordNet_WordNet {
  PyObject *(*readExceptionFile)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*addLiteralToLiteralList)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, struct __pyx_obj_7WordNet_7Literal_Literal *, int __pyx_skip_dispatch);
  PyObject *(*synSetList)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, int __pyx_skip_dispatch);
  PyObject *(*literalList)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, int __pyx_skip_dispatch);
  PyObject *(*addSynSet)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, struct __pyx_obj_7WordNet_6SynSet_SynSet *, int __pyx_skip_dispatch);
  PyObject *(*removeSynSet)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, struct __pyx_obj_7WordNet_6SynSet_SynSet *, int __pyx_skip_dispatch);
  PyObject *(*changeSynSetId)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, struct __pyx_obj_7WordNet_6SynSet_SynSet *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_7WordNet_6SynSet_SynSet *(*getSynSetWithId)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_7WordNet_6SynSet_SynSet *(*getSynSetWithLiteral)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, PyObject *, int, int __pyx_skip_dispatch);
  int (*numberOfSynSetsWithLiteral)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getSynSetsWithPartOfSpeech)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getLiteralsWithName)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*addSynSetsWithLiteralToList)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getSynSetsWithLiteral)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getLiteralsWithPossibleModifiedLiteral)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getSynSetsWithPossiblyModifiedLiteral)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*addReverseRelation)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, struct __pyx_obj_7WordNet_6SynSet_SynSet *, struct __pyx_obj_7WordNet_16SemanticRelation_SemanticRelation *, int __pyx_skip_dispatch);
  PyObject *(*removeReverseRelation)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, struct __pyx_obj_7WordNet_6SynSet_SynSet *, struct __pyx_obj_7WordNet_16SemanticRelation_SemanticRelation *, int __pyx_skip_dispatch);
  PyObject *(*equalizeSemanticRelations)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, int __pyx_skip_dispatch);
  PyObject *(*constructLiterals)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, PyObject *, struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, int __pyx_skip_dispatch);
  PyObject *(*constructSynSets)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, PyObject *, struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, int __pyx_skip_dispatch);
  PyObject *(*constructIdiomLiterals)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, int __pyx_skip_dispatch, struct __pyx_opt_args_7WordNet_7WordNet_7WordNet_constructIdiomLiterals *__pyx_optional_args);
  PyObject *(*constructIdiomSynSets)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, int __pyx_skip_dispatch, struct __pyx_opt_args_7WordNet_7WordNet_7WordNet_constructIdiomSynSets *__pyx_optional_args);
  PyObject *(*sortDefinitions)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, int __pyx_skip_dispatch);
  PyObject *(*getInterlingual)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, PyObject *, int __pyx_skip_dispatch);
  int (*__pyx___containsSameLiteral)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, struct __pyx_obj_7WordNet_6SynSet_SynSet *, struct __pyx_obj_7WordNet_6SynSet_SynSet *, int __pyx_skip_dispatch);
  PyObject *(*saveAsXml)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, PyObject *, int __pyx_skip_dispatch);
  int (*size)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, int __pyx_skip_dispatch);
  int (*findPathLength)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___findLCS)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  int (*findLCSDepth)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*findLCSid)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_7WordNet_6SynSet_SynSet *(*percolateUp)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, struct __pyx_obj_7WordNet_6SynSet_SynSet *, int __pyx_skip_dispatch);
  PyObject *(*findPathToRoot)(struct __pyx_obj_7WordNet_7WordNet_WordNet *, struct __pyx_obj_7WordNet_6SynSet_SynSet *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_7WordNet_7WordNet_WordNet *__pyx_vtabptr_7WordNet_7WordNet_WordNet;


/* "AnnotatedSentence/AnnotatedSentence.pxd":9
 * 
 * 
 * cdef class AnnotatedSentence(Sentence):             # <<<<<<<<<<<<<<
 * 
 *     cdef str __fileName
 */

struct __pyx_vtabstruct_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence {
  struct __pyx_vtabstruct_6Corpus_8Sentence_Sentence __pyx_base;
  PyObject *(*getShallowParseGroups)(struct __pyx_obj_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence *, int __pyx_skip_dispatch);
  int (*containsPredicate)(struct __pyx_obj_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence *, int __pyx_skip_dispatch);
  int (*updateConnectedPredicate)(struct __pyx_obj_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*predicateCandidates)(struct __pyx_obj_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence *, struct __pyx_obj_8PropBank_12FramesetList_FramesetList *, int __pyx_skip_dispatch);
  PyObject *(*predicateFrameCandidates)(struct __pyx_obj_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence *, struct __pyx_obj_8FrameNet_8FrameNet_FrameNet *, int __pyx_skip_dispatch);
  PyObject *(*getPredicate)(struct __pyx_obj_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence *, int, int __pyx_skip_dispatch);
  PyObject *(*getFileName)(struct __pyx_obj_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence *, int __pyx_skip_dispatch);
  PyObject *(*removeWord)(struct __pyx_obj_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence *, int, int __pyx_skip_dispatch);
  PyObject *(*toStems)(struct __pyx_obj_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence *, int __pyx_skip_dispatch);
  struct __pyx_obj_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore *(*compareParses)(struct __pyx_obj_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence *, struct __pyx_obj_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence *, int __pyx_skip_dispatch);
  PyObject *(*save)(struct __pyx_obj_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence *, int __pyx_skip_dispatch);
  PyObject *(*getUniversalDependencyFormat)(struct __pyx_obj_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence *, int __pyx_skip_dispatch, struct __pyx_opt_args_17AnnotatedSentence_17AnnotatedSentence_17AnnotatedSentence_getUniversalDependencyFormat *__pyx_optional_args);
  PyObject *(*constructLiterals)(struct __pyx_obj_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence *, struct __pyx_obj_7WordNet_7WordNet_WordNet *, struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, int, int __pyx_skip_dispatch);
  PyObject *(*constructSynSets)(struct __pyx_obj_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence *, struct __pyx_obj_7WordNet_7WordNet_WordNet *, struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, int, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence *__pyx_vtabptr_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence;


/* "AnnotatedTree/ParseTreeDrawable.pxd":8
 * 
 * 
 * cdef class ParseTreeDrawable(ParseTree):             # <<<<<<<<<<<<<<
 * 
 *     cdef str __name
 */

struct __pyx_vtabstruct_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable {
  struct __pyx_vtabstruct_9ParseTree_9ParseTree_ParseTree __pyx_base;
  PyObject *(*setFileDescription)(struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable *, struct __pyx_obj_6Corpus_15FileDescription_FileDescription *, int __pyx_skip_dispatch);
  struct __pyx_obj_6Corpus_15FileDescription_FileDescription *(*getFileDescription)(struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable *, int __pyx_skip_dispatch);
  PyObject *(*reload)(struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable *, int __pyx_skip_dispatch);
  PyObject *(*readFromFile)(struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*nextTree)(struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable *, int, int __pyx_skip_dispatch);
  PyObject *(*previousTree)(struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable *, int, int __pyx_skip_dispatch);
  PyObject *(*saveWithFileName)(struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable *, int __pyx_skip_dispatch);
  PyObject *(*saveWithPath)(struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable *, PyObject *, int __pyx_skip_dispatch);
  int (*maxDepth)(struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable *, int __pyx_skip_dispatch);
  PyObject *(*moveLeft)(struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable *, struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  PyObject *(*moveRight)(struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable *, struct __pyx_obj_9ParseTree_9ParseNode_ParseNode *, int __pyx_skip_dispatch);
  int (*layerExists)(struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable *, PyObject *, int __pyx_skip_dispatch);
  int (*layerAll)(struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*clearLayer)(struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence *(*generateAnnotatedSentence)(struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable *, int __pyx_skip_dispatch, struct __pyx_opt_args_13AnnotatedTree_17ParseTreeDrawable_17ParseTreeDrawable_generateAnnotatedSentence *__pyx_optional_args);
  struct __pyx_obj_9ParseTree_9ParseTree_ParseTree *(*generateParseTree)(struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable *, int, int __pyx_skip_dispatch);
  PyObject *(*extractNodesWithVerbs)(struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable *, struct __pyx_obj_7WordNet_7WordNet_WordNet *, int __pyx_skip_dispatch);
  PyObject *(*extractNodesWithPredicateVerbs)(struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable *, struct __pyx_obj_7WordNet_7WordNet_WordNet *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable *__pyx_vtabptr_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable;


/* "ParseTree/TreeBank.pxd":4
 * 
 * 
 * cdef class TreeBank:             # <<<<<<<<<<<<<<
 * 
 *     cdef list parseTrees
 */

struct __pyx_vtabstruct_9ParseTree_8TreeBank_TreeBank {
  int (*size)(struct __pyx_obj_9ParseTree_8TreeBank_TreeBank *, int __pyx_skip_dispatch);
  int (*wordCount)(struct __pyx_obj_9ParseTree_8TreeBank_TreeBank *, int, int __pyx_skip_dispatch);
  struct __pyx_obj_9ParseTree_9ParseTree_ParseTree *(*get)(struct __pyx_obj_9ParseTree_8TreeBank_TreeBank *, int, int __pyx_skip_dispatch);
  PyObject *(*removeTree)(struct __pyx_obj_9ParseTree_8TreeBank_TreeBank *, int, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_9ParseTree_8TreeBank_TreeBank *__pyx_vtabptr_9ParseTree_8TreeBank_TreeBank;


/* "AnnotatedTree/TreeBankDrawable.pxd":5
 * 
 * 
 * cdef class TreeBankDrawable(TreeBank):             # <<<<<<<<<<<<<<
 * 
 *     cpdef list getParseTrees(self)
 */

struct __pyx_vtabstruct_13AnnotatedTree_16TreeBankDrawable_TreeBankDrawable {
  struct __pyx_vtabstruct_9ParseTree_8TreeBank_TreeBank __pyx_base;
  PyObject *(*getParseTrees)(struct __pyx_obj_13AnnotatedTree_16TreeBankDrawable_TreeBankDrawable *, int __pyx_skip_dispatch);
  struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable *(*get)(struct __pyx_obj_13AnnotatedTree_16TreeBankDrawable_TreeBankDrawable *, int, int __pyx_skip_dispatch);
  PyObject *(*clearLayer)(struct __pyx_obj_13AnnotatedTree_16TreeBankDrawable_TreeBankDrawable *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_13AnnotatedTree_16TreeBankDrawable_TreeBankDrawable *__pyx_vtabptr_13AnnotatedTree_16TreeBankDrawable_TreeBankDrawable;


/* "Classification/FeatureSelection/FeatureSubSet.pxd":1
 * cdef class FeatureSubSet(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef list __indexList
 */

struct __pyx_vtabstruct_14Classification_16FeatureSelection_13FeatureSubSet_FeatureSubSet {
  int (*size)(struct __pyx_obj_14Classification_16FeatureSelection_13FeatureSubSet_FeatureSubSet *, int __pyx_skip_dispatch);
  int (*get)(struct __pyx_obj_14Classification_16FeatureSelection_13FeatureSubSet_FeatureSubSet *, int, int __pyx_skip_dispatch);
  int (*contains)(struct __pyx_obj_14Classification_16FeatureSelection_13FeatureSubSet_FeatureSubSet *, int, int __pyx_skip_dispatch);
  PyObject *(*add)(struct __pyx_obj_14Classification_16FeatureSelection_13FeatureSubSet_FeatureSubSet *, int, int __pyx_skip_dispatch);
  PyObject *(*remove)(struct __pyx_obj_14Classification_16FeatureSelection_13FeatureSubSet_FeatureSubSet *, int, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_14Classification_16FeatureSelection_13FeatureSubSet_FeatureSubSet *__pyx_vtabptr_14Classification_16FeatureSelection_13FeatureSubSet_FeatureSubSet;


/* "Classification/Attribute/Attribute.pxd":1
 * cdef class Attribute(object):             # <<<<<<<<<<<<<<
 * 
 *     cpdef int continuousAttributeSize(self)
 */

struct __pyx_vtabstruct_14Classification_9Attribute_9Attribute_Attribute {
  int (*continuousAttributeSize)(struct __pyx_obj_14Classification_9Attribute_9Attribute_Attribute *, int __pyx_skip_dispatch);
  PyObject *(*continuousAttributes)(struct __pyx_obj_14Classification_9Attribute_9Attribute_Attribute *, int __pyx_skip_dispatch);
  PyObject *(*getValue)(struct __pyx_obj_14Classification_9Attribute_9Attribute_Attribute *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_14Classification_9Attribute_9Attribute_Attribute *__pyx_vtabptr_14Classification_9Attribute_9Attribute_Attribute;


/* "Math/Vector.pxd":1
 * cdef class Vector(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef int __size
 */

struct __pyx_vtabstruct_4Math_6Vector_Vector {
  PyObject *(*initAllSame)(struct __pyx_obj_4Math_6Vector_Vector *, int, double, int __pyx_skip_dispatch);
  PyObject *(*initAllZerosExceptOne)(struct __pyx_obj_4Math_6Vector_Vector *, int, int, double, int __pyx_skip_dispatch);
  struct __pyx_obj_4Math_6Vector_Vector *(*biased)(struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  PyObject *(*add)(struct __pyx_obj_4Math_6Vector_Vector *, double, int __pyx_skip_dispatch);
  PyObject *(*insert)(struct __pyx_obj_4Math_6Vector_Vector *, int, double, int __pyx_skip_dispatch);
  PyObject *(*remove)(struct __pyx_obj_4Math_6Vector_Vector *, int, int __pyx_skip_dispatch);
  PyObject *(*clear)(struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  double (*sumOfElements)(struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  int (*maxIndex)(struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  PyObject *(*sigmoid)(struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  PyObject *(*tanh)(struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  PyObject *(*relu)(struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  PyObject *(*reluDerivative)(struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  struct __pyx_obj_4Math_6Vector_Vector *(*skipVector)(struct __pyx_obj_4Math_6Vector_Vector *, int, int, int __pyx_skip_dispatch);
  PyObject *(*addVector)(struct __pyx_obj_4Math_6Vector_Vector *, struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  PyObject *(*subtract)(struct __pyx_obj_4Math_6Vector_Vector *, struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  struct __pyx_obj_4Math_6Vector_Vector *(*difference)(struct __pyx_obj_4Math_6Vector_Vector *, struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  double (*dotProduct)(struct __pyx_obj_4Math_6Vector_Vector *, struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  double (*dotProductWithSelf)(struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  struct __pyx_obj_4Math_6Vector_Vector *(*elementProduct)(struct __pyx_obj_4Math_6Vector_Vector *, struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  PyObject *(*divide)(struct __pyx_obj_4Math_6Vector_Vector *, double, int __pyx_skip_dispatch);
  PyObject *(*multiply)(struct __pyx_obj_4Math_6Vector_Vector *, double, int __pyx_skip_dispatch);
  struct __pyx_obj_4Math_6Vector_Vector *(*product)(struct __pyx_obj_4Math_6Vector_Vector *, double, int __pyx_skip_dispatch);
  PyObject *(*l1Normalize)(struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  double (*l2Norm)(struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  double (*cosineSimilarity)(struct __pyx_obj_4Math_6Vector_Vector *, struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  int (*size)(struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  double (*getValue)(struct __pyx_obj_4Math_6Vector_Vector *, int, int __pyx_skip_dispatch);
  PyObject *(*setValue)(struct __pyx_obj_4Math_6Vector_Vector *, int, double, int __pyx_skip_dispatch);
  PyObject *(*addValue)(struct __pyx_obj_4Math_6Vector_Vector *, int, double, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_4Math_6Vector_Vector *__pyx_vtabptr_4Math_6Vector_Vector;


/* "Classification/Instance/Instance.pxd":6
 * 
 * 
 * cdef class Instance(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef str __classLabel
 */

struct __pyx_vtabstruct_14Classification_8Instance_8Instance_Instance {
  PyObject *(*addDiscreteAttribute)(struct __pyx_obj_14Classification_8Instance_8Instance_Instance *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*addContinuousAttribute)(struct __pyx_obj_14Classification_8Instance_8Instance_Instance *, double, int __pyx_skip_dispatch);
  PyObject *(*addAttribute)(struct __pyx_obj_14Classification_8Instance_8Instance_Instance *, struct __pyx_obj_14Classification_9Attribute_9Attribute_Attribute *, int __pyx_skip_dispatch);
  PyObject *(*addVectorAttribute)(struct __pyx_obj_14Classification_8Instance_8Instance_Instance *, struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  PyObject *(*removeAttribute)(struct __pyx_obj_14Classification_8Instance_8Instance_Instance *, int, int __pyx_skip_dispatch);
  PyObject *(*removeAllAttributes)(struct __pyx_obj_14Classification_8Instance_8Instance_Instance *, int __pyx_skip_dispatch);
  struct __pyx_obj_14Classification_9Attribute_9Attribute_Attribute *(*getAttribute)(struct __pyx_obj_14Classification_8Instance_8Instance_Instance *, int, int __pyx_skip_dispatch);
  int (*attributeSize)(struct __pyx_obj_14Classification_8Instance_8Instance_Instance *, int __pyx_skip_dispatch);
  int (*continuousAttributeSize)(struct __pyx_obj_14Classification_8Instance_8Instance_Instance *, int __pyx_skip_dispatch);
  PyObject *(*continuousAttributes)(struct __pyx_obj_14Classification_8Instance_8Instance_Instance *, int __pyx_skip_dispatch);
  PyObject *(*getClassLabel)(struct __pyx_obj_14Classification_8Instance_8Instance_Instance *, int __pyx_skip_dispatch);
  struct __pyx_obj_14Classification_8Instance_8Instance_Instance *(*getSubSetOfFeatures)(struct __pyx_obj_14Classification_8Instance_8Instance_Instance *, struct __pyx_obj_14Classification_16FeatureSelection_13FeatureSubSet_FeatureSubSet *, int __pyx_skip_dispatch);
  struct __pyx_obj_4Math_6Vector_Vector *(*toVector)(struct __pyx_obj_14Classification_8Instance_8Instance_Instance *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_14Classification_8Instance_8Instance_Instance *__pyx_vtabptr_14Classification_8Instance_8Instance_Instance;


/* "Sampling/Bootstrap.pxd":1
 * cdef class Bootstrap:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __instanceList
 */

struct __pyx_vtabstruct_8Sampling_9Bootstrap_Bootstrap {
  PyObject *(*getSample)(struct __pyx_obj_8Sampling_9Bootstrap_Bootstrap *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_8Sampling_9Bootstrap_Bootstrap *__pyx_vtabptr_8Sampling_9Bootstrap_Bootstrap;


/* "Math/DiscreteDistribution.pxd":1
 * cdef class DiscreteDistribution(dict):             # <<<<<<<<<<<<<<
 * 
 *     cdef double __sum
 */

struct __pyx_vtabstruct_4Math_20DiscreteDistribution_DiscreteDistribution {
  PyObject *(*addItem)(struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*removeItem)(struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*addDistribution)(struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution *, struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution *, int __pyx_skip_dispatch);
  PyObject *(*removeDistribution)(struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution *, struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution *, int __pyx_skip_dispatch);
  double (*getSum)(struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution *, int __pyx_skip_dispatch);
  int (*getIndex)(struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution *, PyObject *, int __pyx_skip_dispatch);
  int (*containsItem)(struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getItem)(struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution *, int, int __pyx_skip_dispatch);
  int (*getValue)(struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution *, int, int __pyx_skip_dispatch);
  int (*getCount)(struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getMaxItem)(struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution *, int __pyx_skip_dispatch);
  PyObject *(*getMaxItemIncludeTheseOnly)(struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution *, PyObject *, int __pyx_skip_dispatch);
  double (*getProbability)(struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getProbabilityDistribution)(struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution *, int __pyx_skip_dispatch);
  double (*getProbabilityLaplaceSmoothing)(struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution *, PyObject *, int __pyx_skip_dispatch);
  double (*entropy)(struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_4Math_20DiscreteDistribution_DiscreteDistribution *__pyx_vtabptr_4Math_20DiscreteDistribution_DiscreteDistribution;


/* "Math/Matrix.pxd":4
 * 
 * 
 * cdef class Matrix(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef int __row, __col
 */

struct __pyx_vtabstruct_4Math_6Matrix_Matrix {
  PyObject *(*initZeros)(struct __pyx_obj_4Math_6Matrix_Matrix *, int __pyx_skip_dispatch);
  struct __pyx_obj_4Math_6Matrix_Matrix *(*clone)(struct __pyx_obj_4Math_6Matrix_Matrix *, int __pyx_skip_dispatch);
  double (*getValue)(struct __pyx_obj_4Math_6Matrix_Matrix *, int, int, int __pyx_skip_dispatch);
  PyObject *(*setValue)(struct __pyx_obj_4Math_6Matrix_Matrix *, int, int, double, int __pyx_skip_dispatch);
  PyObject *(*addValue)(struct __pyx_obj_4Math_6Matrix_Matrix *, int, int, double, int __pyx_skip_dispatch);
  PyObject *(*increment)(struct __pyx_obj_4Math_6Matrix_Matrix *, int, int, int __pyx_skip_dispatch);
  int (*getRow)(struct __pyx_obj_4Math_6Matrix_Matrix *, int __pyx_skip_dispatch);
  struct __pyx_obj_4Math_6Vector_Vector *(*getRowVector)(struct __pyx_obj_4Math_6Matrix_Matrix *, int, int __pyx_skip_dispatch);
  int (*getColumn)(struct __pyx_obj_4Math_6Matrix_Matrix *, int __pyx_skip_dispatch);
  PyObject *(*getColumnVector)(struct __pyx_obj_4Math_6Matrix_Matrix *, int, int __pyx_skip_dispatch);
  PyObject *(*columnWiseNormalize)(struct __pyx_obj_4Math_6Matrix_Matrix *, int __pyx_skip_dispatch);
  PyObject *(*multiplyWithConstant)(struct __pyx_obj_4Math_6Matrix_Matrix *, double, int __pyx_skip_dispatch);
  PyObject *(*divideByConstant)(struct __pyx_obj_4Math_6Matrix_Matrix *, double, int __pyx_skip_dispatch);
  PyObject *(*add)(struct __pyx_obj_4Math_6Matrix_Matrix *, struct __pyx_obj_4Math_6Matrix_Matrix *, int __pyx_skip_dispatch);
  PyObject *(*addRowVector)(struct __pyx_obj_4Math_6Matrix_Matrix *, int, struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  PyObject *(*subtract)(struct __pyx_obj_4Math_6Matrix_Matrix *, struct __pyx_obj_4Math_6Matrix_Matrix *, int __pyx_skip_dispatch);
  struct __pyx_obj_4Math_6Vector_Vector *(*multiplyWithVectorFromLeft)(struct __pyx_obj_4Math_6Matrix_Matrix *, struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  struct __pyx_obj_4Math_6Vector_Vector *(*multiplyWithVectorFromRight)(struct __pyx_obj_4Math_6Matrix_Matrix *, struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  double (*columnSum)(struct __pyx_obj_4Math_6Matrix_Matrix *, int, int __pyx_skip_dispatch);
  struct __pyx_obj_4Math_6Vector_Vector *(*sumOfRows)(struct __pyx_obj_4Math_6Matrix_Matrix *, int __pyx_skip_dispatch);
  double (*rowSum)(struct __pyx_obj_4Math_6Matrix_Matrix *, int, int __pyx_skip_dispatch);
  struct __pyx_obj_4Math_6Matrix_Matrix *(*multiply)(struct __pyx_obj_4Math_6Matrix_Matrix *, struct __pyx_obj_4Math_6Matrix_Matrix *, int __pyx_skip_dispatch);
  struct __pyx_obj_4Math_6Matrix_Matrix *(*elementProduct)(struct __pyx_obj_4Math_6Matrix_Matrix *, struct __pyx_obj_4Math_6Matrix_Matrix *, int __pyx_skip_dispatch);
  double (*sumOfElements)(struct __pyx_obj_4Math_6Matrix_Matrix *, int __pyx_skip_dispatch);
  double (*trace)(struct __pyx_obj_4Math_6Matrix_Matrix *, int __pyx_skip_dispatch);
  struct __pyx_obj_4Math_6Matrix_Matrix *(*transpose)(struct __pyx_obj_4Math_6Matrix_Matrix *, int __pyx_skip_dispatch);
  struct __pyx_obj_4Math_6Matrix_Matrix *(*partial)(struct __pyx_obj_4Math_6Matrix_Matrix *, int, int, int, int, int __pyx_skip_dispatch);
  int (*isSymmetric)(struct __pyx_obj_4Math_6Matrix_Matrix *, int __pyx_skip_dispatch);
  double (*determinant)(struct __pyx_obj_4Math_6Matrix_Matrix *, int __pyx_skip_dispatch);
  PyObject *(*inverse)(struct __pyx_obj_4Math_6Matrix_Matrix *, int __pyx_skip_dispatch);
  struct __pyx_obj_4Math_6Matrix_Matrix *(*choleskyDecomposition)(struct __pyx_obj_4Math_6Matrix_Matrix *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___rotate)(struct __pyx_obj_4Math_6Matrix_Matrix *, double, double, int, int, int, int, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_4Math_6Matrix_Matrix *__pyx_vtabptr_4Math_6Matrix_Matrix;


/* "Classification/InstanceList/InstanceList.pxd":9
 * 
 * 
 * cdef class InstanceList(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef list list
 */

struct __pyx_vtabstruct_14Classification_12InstanceList_12InstanceList_InstanceList {
  PyObject *(*add)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, struct __pyx_obj_14Classification_8Instance_8Instance_Instance *, int __pyx_skip_dispatch);
  PyObject *(*addAll)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, PyObject *, int __pyx_skip_dispatch);
  int (*size)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int __pyx_skip_dispatch);
  struct __pyx_obj_14Classification_8Instance_8Instance_Instance *(*get)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int, int __pyx_skip_dispatch);
  PyObject *(*sortWrtAttribute)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int, int __pyx_skip_dispatch);
  PyObject *(*sort)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int __pyx_skip_dispatch);
  PyObject *(*shuffle)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int, int __pyx_skip_dispatch);
  struct __pyx_obj_8Sampling_9Bootstrap_Bootstrap *(*bootstrap)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int, int __pyx_skip_dispatch);
  PyObject *(*getClassLabels)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int __pyx_skip_dispatch);
  PyObject *(*getDistinctClassLabels)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int __pyx_skip_dispatch);
  PyObject *(*getUnionOfPossibleClassLabels)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int __pyx_skip_dispatch);
  PyObject *(*getAttributeValueList)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int, int __pyx_skip_dispatch);
  struct __pyx_obj_14Classification_9Attribute_9Attribute_Attribute *(*__pyx___attributeAverage)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int, int __pyx_skip_dispatch);
  PyObject *(*continuousAttributeAverage)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int, int __pyx_skip_dispatch);
  struct __pyx_obj_14Classification_9Attribute_9Attribute_Attribute *(*__pyx___attributeStandardDeviation)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int, int __pyx_skip_dispatch);
  PyObject *(*continuousAttributeStandardDeviation)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int, int __pyx_skip_dispatch);
  struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution *(*attributeDistribution)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int, int __pyx_skip_dispatch);
  PyObject *(*attributeClassDistribution)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int, int __pyx_skip_dispatch);
  struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution *(*discreteIndexedAttributeClassDistribution)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int, int, int __pyx_skip_dispatch);
  struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution *(*classDistribution)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int __pyx_skip_dispatch);
  PyObject *(*allAttributesDistribution)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int __pyx_skip_dispatch);
  struct __pyx_obj_14Classification_8Instance_8Instance_Instance *(*average)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int __pyx_skip_dispatch);
  PyObject *(*continuousAverage)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int __pyx_skip_dispatch);
  struct __pyx_obj_14Classification_8Instance_8Instance_Instance *(*standardDeviation)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int __pyx_skip_dispatch);
  PyObject *(*continuousStandardDeviation)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int __pyx_skip_dispatch);
  struct __pyx_obj_4Math_6Matrix_Matrix *(*covariance)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, struct __pyx_obj_4Math_6Vector_Vector *, int __pyx_skip_dispatch);
  PyObject *(*getInstances)(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_14Classification_12InstanceList_12InstanceList_InstanceList *__pyx_vtabptr_14Classification_12InstanceList_12InstanceList_InstanceList;


/* "Classification/DataSet/DataDefinition.pxd":4
 * 
 * 
 * cdef class DataDefinition(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef list __attributeTypes
 */

struct __pyx_vtabstruct_14Classification_7DataSet_14DataDefinition_DataDefinition {
  int (*attributeCount)(struct __pyx_obj_14Classification_7DataSet_14DataDefinition_DataDefinition *, int __pyx_skip_dispatch);
  int (*discreteAttributeCount)(struct __pyx_obj_14Classification_7DataSet_14DataDefinition_DataDefinition *, int __pyx_skip_dispatch);
  int (*continuousAttributeCount)(struct __pyx_obj_14Classification_7DataSet_14DataDefinition_DataDefinition *, int __pyx_skip_dispatch);
  PyObject *(*getAttributeType)(struct __pyx_obj_14Classification_7DataSet_14DataDefinition_DataDefinition *, int, int __pyx_skip_dispatch);
  PyObject *(*addAttribute)(struct __pyx_obj_14Classification_7DataSet_14DataDefinition_DataDefinition *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*removeAttribute)(struct __pyx_obj_14Classification_7DataSet_14DataDefinition_DataDefinition *, int, int __pyx_skip_dispatch);
  PyObject *(*removeAllAtrributes)(struct __pyx_obj_14Classification_7DataSet_14DataDefinition_DataDefinition *, int __pyx_skip_dispatch);
  struct __pyx_obj_14Classification_7DataSet_14DataDefinition_DataDefinition *(*getSubSetOfFeatures)(struct __pyx_obj_14Classification_7DataSet_14DataDefinition_DataDefinition *, struct __pyx_obj_14Classification_16FeatureSelection_13FeatureSubSet_FeatureSubSet *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_14Classification_7DataSet_14DataDefinition_DataDefinition *__pyx_vtabptr_14Classification_7DataSet_14DataDefinition_DataDefinition;


/* "Classification/DataSet/DataSet.pxd":7
 * 
 * 
 * cdef class DataSet(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef InstanceList __instances
 */

struct __pyx_vtabstruct_14Classification_7DataSet_7DataSet_DataSet {
  PyObject *(*initWithFile)(struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet *, PyObject *, int __pyx_skip_dispatch);
  int (*__pyx___checkDefinition)(struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet *, struct __pyx_obj_14Classification_8Instance_8Instance_Instance *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___setDefinition)(struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet *, struct __pyx_obj_14Classification_8Instance_8Instance_Instance *, int __pyx_skip_dispatch);
  int (*sampleSize)(struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet *, int __pyx_skip_dispatch);
  int (*classCount)(struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet *, int __pyx_skip_dispatch);
  int (*attributeCount)(struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet *, int __pyx_skip_dispatch);
  int (*discreteAttributeCount)(struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet *, int __pyx_skip_dispatch);
  int (*continuousAttributeCount)(struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet *, int __pyx_skip_dispatch);
  PyObject *(*getClasses)(struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet *, int __pyx_skip_dispatch);
  PyObject *(*info)(struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*addInstance)(struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet *, struct __pyx_obj_14Classification_8Instance_8Instance_Instance *, int __pyx_skip_dispatch);
  PyObject *(*addInstanceList)(struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getInstances)(struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet *, int __pyx_skip_dispatch);
  PyObject *(*getClassInstances)(struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet *, int __pyx_skip_dispatch);
  struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList *(*getInstanceList)(struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet *, int __pyx_skip_dispatch);
  struct __pyx_obj_14Classification_7DataSet_14DataDefinition_DataDefinition *(*getDataDefinition)(struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet *, int __pyx_skip_dispatch);
  struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet *(*getSubSetOfFeatures)(struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet *, struct __pyx_obj_14Classification_16FeatureSelection_13FeatureSubSet_FeatureSubSet *, int __pyx_skip_dispatch);
  PyObject *(*writeToFile)(struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_14Classification_7DataSet_7DataSet_DataSet *__pyx_vtabptr_14Classification_7DataSet_7DataSet_DataSet;


/* "DataGenerator/InstanceGenerator/InstanceGenerator.pxd":5
 * 
 * 
 * cdef class InstanceGenerator:             # <<<<<<<<<<<<<<
 * 
 *     cdef int windowSize
 */

struct __pyx_vtabstruct_13DataGenerator_17InstanceGenerator_17InstanceGenerator_InstanceGenerator {
  struct __pyx_obj_14Classification_8Instance_8Instance_Instance *(*generateInstanceFromSentence)(struct __pyx_obj_13DataGenerator_17InstanceGenerator_17InstanceGenerator_InstanceGenerator *, struct __pyx_obj_6Corpus_8Sentence_Sentence *, int, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_13DataGenerator_17InstanceGenerator_17InstanceGenerator_InstanceGenerator *__pyx_vtabptr_13DataGenerator_17InstanceGenerator_17InstanceGenerator_InstanceGenerator;


/* "DataGenerator/DatasetGenerator/DataSetGenerator.pxd":7
 * 
 * 
 * cdef class DataSetGenerator:             # <<<<<<<<<<<<<<
 * 
 *     cdef TreeBankDrawable __treeBank
 */

struct __pyx_vtabstruct_13DataGenerator_16DatasetGenerator_16DataSetGenerator_DataSetGenerator {
  PyObject *(*setInstanceGenerator)(struct __pyx_obj_13DataGenerator_16DatasetGenerator_16DataSetGenerator_DataSetGenerator *, struct __pyx_obj_13DataGenerator_17InstanceGenerator_17InstanceGenerator_InstanceGenerator *, int __pyx_skip_dispatch);
  PyObject *(*generateInstanceListFromTree)(struct __pyx_obj_13DataGenerator_16DatasetGenerator_16DataSetGenerator_DataSetGenerator *, struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable *, int __pyx_skip_dispatch);
  struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet *(*generate)(struct __pyx_obj_13DataGenerator_16DatasetGenerator_16DataSetGenerator_DataSetGenerator *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_13DataGenerator_16DatasetGenerator_16DataSetGenerator_DataSetGenerator *__pyx_vtabptr_13DataGenerator_16DatasetGenerator_16DataSetGenerator_DataSetGenerator;


/* "DataGenerator/InstanceGenerator/RootWordInstanceGenerator.pxd":6
 * 
 * 
 * cdef class RootWordInstanceGenerator(InstanceGenerator):             # <<<<<<<<<<<<<<
 * 
 *     cpdef addAttributesForPreviousWords(self, Instance current, Sentence sentence, int wordIndex)
 */

struct __pyx_vtabstruct_13DataGenerator_17InstanceGenerator_25RootWordInstanceGenerator_RootWordInstanceGenerator {
  struct __pyx_vtabstruct_13DataGenerator_17InstanceGenerator_17InstanceGenerator_InstanceGenerator __pyx_base;
  PyObject *(*addAttributesForPreviousWords)(struct __pyx_obj_13DataGenerator_17InstanceGenerator_25RootWordInstanceGenerator_RootWordInstanceGenerator *, struct __pyx_obj_14Classification_8Instance_8Instance_Instance *, struct __pyx_obj_6Corpus_8Sentence_Sentence *, int, int __pyx_skip_dispatch);
  PyObject *(*addAttributesForEmptyWords)(struct __pyx_obj_13DataGenerator_17InstanceGenerator_25RootWordInstanceGenerator_RootWordInstanceGenerator *, struct __pyx_obj_14Classification_8Instance_8Instance_Instance *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_13DataGenerator_17InstanceGenerator_25RootWordInstanceGenerator_RootWordInstanceGenerator *__pyx_vtabptr_13DataGenerator_17InstanceGenerator_25RootWordInstanceGenerator_RootWordInstanceGenerator;

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely((Py_TYPE(obj) == type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto
#define __PYX_HAVE_RT_ImportType_proto
enum __Pyx_ImportType_CheckSize {
   __Pyx_ImportType_CheckSize_Error = 0,
   __Pyx_ImportType_CheckSize_Warn = 1,
   __Pyx_ImportType_CheckSize_Ignore = 2
};
static PyTypeObject *__Pyx_ImportType(PyObject* module, const char *module_name, const char *class_name, size_t size, enum __Pyx_ImportType_CheckSize check_size);
#endif

/* GetVTable.proto */
static void* __Pyx_GetVtable(PyObject *dict);

/* CalculateMetaclass.proto */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* FetchCommonType.proto */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);

/* CythonFunctionShared.proto */
#define __Pyx_CyFunction_USED 1
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#define __Pyx_CyFunction_GetClassObj(f)\
    (((__pyx_CyFunctionObject *) (f))->func_classobj)
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
    PyCFunctionObject func;
#if PY_VERSION_HEX < 0x030500A0
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
    PyObject *func_classobj;
    void *defaults;
    int defaults_pyobjects;
    size_t defaults_size;  // used by FusedFunction for copying defaults
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
} __pyx_CyFunctionObject;
static PyTypeObject *__pyx_CyFunctionType = 0;
#define __Pyx_CyFunction_Check(obj)  (__Pyx_TypeCheck(obj, __pyx_CyFunctionType))
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *self,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(void);

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* CyFunctionClassCell.proto */
static int __Pyx_CyFunction_InitClassCell(PyObject *cyfunctions, PyObject *classobj);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);


/* Module declarations from 'Dictionary.Word' */
static PyTypeObject *__pyx_ptype_10Dictionary_4Word_Word = 0;

/* Module declarations from 'ParseTree.Symbol' */
static PyTypeObject *__pyx_ptype_9ParseTree_6Symbol_Symbol = 0;

/* Module declarations from 'ParseTree.ParseNode' */
static PyTypeObject *__pyx_ptype_9ParseTree_9ParseNode_ParseNode = 0;

/* Module declarations from 'ParseTree.ParseTree' */
static PyTypeObject *__pyx_ptype_9ParseTree_9ParseTree_ParseTree = 0;

/* Module declarations from 'Corpus.FileDescription' */
static PyTypeObject *__pyx_ptype_6Corpus_15FileDescription_FileDescription = 0;

/* Module declarations from 'Corpus.Sentence' */
static PyTypeObject *__pyx_ptype_6Corpus_8Sentence_Sentence = 0;

/* Module declarations from 'DependencyParser.ParserEvaluationScore' */
static PyTypeObject *__pyx_ptype_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore = 0;

/* Module declarations from 'Dictionary.Trie.TrieNode' */
static PyTypeObject *__pyx_ptype_10Dictionary_4Trie_8TrieNode_TrieNode = 0;

/* Module declarations from 'Dictionary.TxtWord' */
static PyTypeObject *__pyx_ptype_10Dictionary_7TxtWord_TxtWord = 0;

/* Module declarations from 'Dictionary.Trie.Trie' */
static PyTypeObject *__pyx_ptype_10Dictionary_4Trie_4Trie_Trie = 0;

/* Module declarations from 'Dictionary.Dictionary' */
static PyTypeObject *__pyx_ptype_10Dictionary_10Dictionary_Dictionary = 0;

/* Module declarations from 'Dictionary.TxtDictionary' */
static PyTypeObject *__pyx_ptype_10Dictionary_13TxtDictionary_TxtDictionary = 0;

/* Module declarations from 'DataStructure.Cache.LRUCache' */
static PyTypeObject *__pyx_ptype_13DataStructure_5Cache_8LRUCache_LRUCache = 0;

/* Module declarations from 'MorphologicalAnalysis.InflectionalGroup' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup = 0;

/* Module declarations from 'MorphologicalAnalysis.MorphologicalParse' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse = 0;

/* Module declarations from 'MorphologicalAnalysis.State' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_5State_State = 0;

/* Module declarations from 'MorphologicalAnalysis.FsmParse' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse = 0;

/* Module declarations from 'MorphologicalAnalysis.FiniteStateMachine' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine = 0;

/* Module declarations from 'MorphologicalAnalysis.MetamorphicParse' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse = 0;

/* Module declarations from 'MorphologicalAnalysis.FsmMorphologicalAnalyzer' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer = 0;

/* Module declarations from 'PropBank.Frameset' */
static PyTypeObject *__pyx_ptype_8PropBank_8Frameset_Frameset = 0;

/* Module declarations from 'PropBank.FramesetList' */
static PyTypeObject *__pyx_ptype_8PropBank_12FramesetList_FramesetList = 0;

/* Module declarations from 'FrameNet.Frame' */
static PyTypeObject *__pyx_ptype_8FrameNet_5Frame_Frame = 0;

/* Module declarations from 'FrameNet.FrameNet' */
static PyTypeObject *__pyx_ptype_8FrameNet_8FrameNet_FrameNet = 0;

/* Module declarations from 'WordNet.Relation' */
static PyTypeObject *__pyx_ptype_7WordNet_8Relation_Relation = 0;

/* Module declarations from 'WordNet.Literal' */
static PyTypeObject *__pyx_ptype_7WordNet_7Literal_Literal = 0;

/* Module declarations from 'WordNet.SemanticRelation' */
static PyTypeObject *__pyx_ptype_7WordNet_16SemanticRelation_SemanticRelation = 0;

/* Module declarations from 'WordNet.InterlingualRelation' */
static PyTypeObject *__pyx_ptype_7WordNet_20InterlingualRelation_InterlingualRelation = 0;

/* Module declarations from 'WordNet.Synonym' */
static PyTypeObject *__pyx_ptype_7WordNet_7Synonym_Synonym = 0;

/* Module declarations from 'WordNet.SynSet' */
static PyTypeObject *__pyx_ptype_7WordNet_6SynSet_SynSet = 0;

/* Module declarations from 'WordNet.WordNet' */
static PyTypeObject *__pyx_ptype_7WordNet_7WordNet_WordNet = 0;

/* Module declarations from 'AnnotatedSentence.AnnotatedSentence' */
static PyTypeObject *__pyx_ptype_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence = 0;

/* Module declarations from 'AnnotatedTree.ParseTreeDrawable' */
static PyTypeObject *__pyx_ptype_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable = 0;

/* Module declarations from 'ParseTree.TreeBank' */
static PyTypeObject *__pyx_ptype_9ParseTree_8TreeBank_TreeBank = 0;

/* Module declarations from 'AnnotatedTree.TreeBankDrawable' */
static PyTypeObject *__pyx_ptype_13AnnotatedTree_16TreeBankDrawable_TreeBankDrawable = 0;

/* Module declarations from 'Classification.FeatureSelection.FeatureSubSet' */
static PyTypeObject *__pyx_ptype_14Classification_16FeatureSelection_13FeatureSubSet_FeatureSubSet = 0;

/* Module declarations from 'Classification.Attribute.Attribute' */
static PyTypeObject *__pyx_ptype_14Classification_9Attribute_9Attribute_Attribute = 0;

/* Module declarations from 'Math.Vector' */
static PyTypeObject *__pyx_ptype_4Math_6Vector_Vector = 0;

/* Module declarations from 'Classification.Instance.Instance' */
static PyTypeObject *__pyx_ptype_14Classification_8Instance_8Instance_Instance = 0;

/* Module declarations from 'Sampling.Bootstrap' */
static PyTypeObject *__pyx_ptype_8Sampling_9Bootstrap_Bootstrap = 0;

/* Module declarations from 'Math.DiscreteDistribution' */
static PyTypeObject *__pyx_ptype_4Math_20DiscreteDistribution_DiscreteDistribution = 0;

/* Module declarations from 'Math.Matrix' */
static PyTypeObject *__pyx_ptype_4Math_6Matrix_Matrix = 0;

/* Module declarations from 'Classification.InstanceList.InstanceList' */
static PyTypeObject *__pyx_ptype_14Classification_12InstanceList_12InstanceList_InstanceList = 0;

/* Module declarations from 'Classification.DataSet.DataDefinition' */
static PyTypeObject *__pyx_ptype_14Classification_7DataSet_14DataDefinition_DataDefinition = 0;

/* Module declarations from 'Classification.DataSet.DataSet' */
static PyTypeObject *__pyx_ptype_14Classification_7DataSet_7DataSet_DataSet = 0;

/* Module declarations from 'DataGenerator.InstanceGenerator.InstanceGenerator' */
static PyTypeObject *__pyx_ptype_13DataGenerator_17InstanceGenerator_17InstanceGenerator_InstanceGenerator = 0;

/* Module declarations from 'DataGenerator.DatasetGenerator.DataSetGenerator' */
static PyTypeObject *__pyx_ptype_13DataGenerator_16DatasetGenerator_16DataSetGenerator_DataSetGenerator = 0;

/* Module declarations from 'DataGenerator.InstanceGenerator.RootWordInstanceGenerator' */
static PyTypeObject *__pyx_ptype_13DataGenerator_17InstanceGenerator_25RootWordInstanceGenerator_RootWordInstanceGenerator = 0;

/* Module declarations from 'DataGenerator.DatasetGenerator.RootWordDataSetGenerator' */
#define __Pyx_MODULE_NAME "DataGenerator.DatasetGenerator.RootWordDataSetGenerator"
extern int __pyx_module_is_main_DataGenerator__DatasetGenerator__RootWordDataSetGenerator;
int __pyx_module_is_main_DataGenerator__DatasetGenerator__RootWordDataSetGenerator = 0;

/* Implementation of 'DataGenerator.DatasetGenerator.RootWordDataSetGenerator' */
static PyObject *__pyx_builtin_super;
static const char __pyx_k_doc[] = "__doc__";
static const char __pyx_k_init[] = "__init__";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_name[] = "__name__";
static const char __pyx_k_self[] = "self";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_super[] = "super";
static const char __pyx_k_folder[] = "folder";
static const char __pyx_k_module[] = "__module__";
static const char __pyx_k_pattern[] = "pattern";
static const char __pyx_k_prepare[] = "__prepare__";
static const char __pyx_k_unicode[] = "unicode";
static const char __pyx_k_qualname[] = "__qualname__";
static const char __pyx_k_metaclass[] = "__metaclass__";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_RootWordDataSetGenerator[] = "RootWordDataSetGenerator";
static const char __pyx_k_RootWordInstanceGenerator[] = "RootWordInstanceGenerator";
static const char __pyx_k_rootWordInstanceGenerator[] = "rootWordInstanceGenerator";
static const char __pyx_k_RootWordDataSetGenerator___init[] = "RootWordDataSetGenerator.__init__";
static const char __pyx_k_DataGenerator_DatasetGenerator_R[] = "DataGenerator.DatasetGenerator.RootWordDataSetGenerator";
static const char __pyx_k_DataGenerator_DatasetGenerator_R_2[] = "DataGenerator/DatasetGenerator/RootWordDataSetGenerator.pyx";
static PyObject *__pyx_n_s_DataGenerator_DatasetGenerator_R;
static PyObject *__pyx_kp_s_DataGenerator_DatasetGenerator_R_2;
static PyObject *__pyx_n_s_RootWordDataSetGenerator;
static PyObject *__pyx_n_s_RootWordDataSetGenerator___init;
static PyObject *__pyx_n_u_RootWordInstanceGenerator;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_s_doc;
static PyObject *__pyx_n_s_folder;
static PyObject *__pyx_n_s_init;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_metaclass;
static PyObject *__pyx_n_s_module;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_s_pattern;
static PyObject *__pyx_n_s_prepare;
static PyObject *__pyx_n_s_pyx_vtable;
static PyObject *__pyx_n_s_qualname;
static PyObject *__pyx_n_s_rootWordInstanceGenerator;
static PyObject *__pyx_n_s_self;
static PyObject *__pyx_n_s_super;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_u_unicode;
static PyObject *__pyx_pf_13DataGenerator_16DatasetGenerator_24RootWordDataSetGenerator_24RootWordDataSetGenerator___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_folder, PyObject *__pyx_v_pattern, struct __pyx_obj_13DataGenerator_17InstanceGenerator_25RootWordInstanceGenerator_RootWordInstanceGenerator *__pyx_v_rootWordInstanceGenerator); /* proto */
static PyObject *__pyx_tuple_;
static PyObject *__pyx_codeobj__2;
/* Late includes */

/* "DataGenerator/DatasetGenerator/RootWordDataSetGenerator.pyx":7
 * class RootWordDataSetGenerator(DataSetGenerator):
 * 
 *     def __init__(self, folder: str, pattern: str, rootWordInstanceGenerator: RootWordInstanceGenerator):             # <<<<<<<<<<<<<<
 *         """
 *         Constructor for the RootWordDataSetGenerator which takes input the data directory, the pattern for the training
 */

/* Python wrapper */
static PyObject *__pyx_pw_13DataGenerator_16DatasetGenerator_24RootWordDataSetGenerator_24RootWordDataSetGenerator_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_13DataGenerator_16DatasetGenerator_24RootWordDataSetGenerator_24RootWordDataSetGenerator___init__[] = "\n        Constructor for the RootWordDataSetGenerator which takes input the data directory, the pattern for the training\n        files included, and an instanceGenerator. The constructor calls its super class with these inputs.\n\n        PARAMETERS\n        ----------\n        folder : str\n            Directory where the treebank files reside.\n        pattern : str\n            Pattern of the tree files to be included in the treebank. Use \".\" for all files.\n        rootWordInstanceGenerator : RootWordInstanceGenerator\n            The instance generator used to generate the dataset.\n        ";
static PyMethodDef __pyx_mdef_13DataGenerator_16DatasetGenerator_24RootWordDataSetGenerator_24RootWordDataSetGenerator_1__init__ = {"__init__", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_13DataGenerator_16DatasetGenerator_24RootWordDataSetGenerator_24RootWordDataSetGenerator_1__init__, METH_VARARGS|METH_KEYWORDS, __pyx_doc_13DataGenerator_16DatasetGenerator_24RootWordDataSetGenerator_24RootWordDataSetGenerator___init__};
static PyObject *__pyx_pw_13DataGenerator_16DatasetGenerator_24RootWordDataSetGenerator_24RootWordDataSetGenerator_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_folder = 0;
  PyObject *__pyx_v_pattern = 0;
  struct __pyx_obj_13DataGenerator_17InstanceGenerator_25RootWordInstanceGenerator_RootWordInstanceGenerator *__pyx_v_rootWordInstanceGenerator = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_folder,&__pyx_n_s_pattern,&__pyx_n_s_rootWordInstanceGenerator,0};
    PyObject* values[4] = {0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_folder)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, 1); __PYX_ERR(0, 7, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pattern)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, 2); __PYX_ERR(0, 7, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_rootWordInstanceGenerator)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, 3); __PYX_ERR(0, 7, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 7, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 4) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
    }
    __pyx_v_self = values[0];
    __pyx_v_folder = ((PyObject*)values[1]);
    __pyx_v_pattern = ((PyObject*)values[2]);
    __pyx_v_rootWordInstanceGenerator = ((struct __pyx_obj_13DataGenerator_17InstanceGenerator_25RootWordInstanceGenerator_RootWordInstanceGenerator *)values[3]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 7, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("DataGenerator.DatasetGenerator.RootWordDataSetGenerator.RootWordDataSetGenerator.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_folder), (&PyUnicode_Type), 1, "folder", 1))) __PYX_ERR(0, 7, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_pattern), (&PyUnicode_Type), 1, "pattern", 1))) __PYX_ERR(0, 7, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_rootWordInstanceGenerator), __pyx_ptype_13DataGenerator_17InstanceGenerator_25RootWordInstanceGenerator_RootWordInstanceGenerator, 1, "rootWordInstanceGenerator", 0))) __PYX_ERR(0, 7, __pyx_L1_error)
  __pyx_r = __pyx_pf_13DataGenerator_16DatasetGenerator_24RootWordDataSetGenerator_24RootWordDataSetGenerator___init__(__pyx_self, __pyx_v_self, __pyx_v_folder, __pyx_v_pattern, __pyx_v_rootWordInstanceGenerator);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_13DataGenerator_16DatasetGenerator_24RootWordDataSetGenerator_24RootWordDataSetGenerator___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_folder, PyObject *__pyx_v_pattern, struct __pyx_obj_13DataGenerator_17InstanceGenerator_25RootWordInstanceGenerator_RootWordInstanceGenerator *__pyx_v_rootWordInstanceGenerator) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "DataGenerator/DatasetGenerator/RootWordDataSetGenerator.pyx":21
 *             The instance generator used to generate the dataset.
 *         """
 *         super().__init__(folder, pattern, rootWordInstanceGenerator)             # <<<<<<<<<<<<<<
 */
  __pyx_t_2 = __Pyx_CyFunction_GetClassObj(__pyx_self);
  if (!__pyx_t_2) { PyErr_SetString(PyExc_SystemError, "super(): empty __class__ cell"); __PYX_ERR(0, 21, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[4] = {__pyx_t_2, __pyx_v_folder, __pyx_v_pattern, ((PyObject *)__pyx_v_rootWordInstanceGenerator)};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 3+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 21, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[4] = {__pyx_t_2, __pyx_v_folder, __pyx_v_pattern, ((PyObject *)__pyx_v_rootWordInstanceGenerator)};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 3+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 21, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(3+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 21, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_INCREF(__pyx_v_folder);
    __Pyx_GIVEREF(__pyx_v_folder);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_folder);
    __Pyx_INCREF(__pyx_v_pattern);
    __Pyx_GIVEREF(__pyx_v_pattern);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_pattern);
    __Pyx_INCREF(((PyObject *)__pyx_v_rootWordInstanceGenerator));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_rootWordInstanceGenerator));
    PyTuple_SET_ITEM(__pyx_t_5, 2+__pyx_t_4, ((PyObject *)__pyx_v_rootWordInstanceGenerator));
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 21, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "DataGenerator/DatasetGenerator/RootWordDataSetGenerator.pyx":7
 * class RootWordDataSetGenerator(DataSetGenerator):
 * 
 *     def __init__(self, folder: str, pattern: str, rootWordInstanceGenerator: RootWordInstanceGenerator):             # <<<<<<<<<<<<<<
 *         """
 *         Constructor for the RootWordDataSetGenerator which takes input the data directory, the pattern for the training
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("DataGenerator.DatasetGenerator.RootWordDataSetGenerator.RootWordDataSetGenerator.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_RootWordDataSetGenerator(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_RootWordDataSetGenerator},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "RootWordDataSetGenerator",
    0, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_n_s_DataGenerator_DatasetGenerator_R, __pyx_k_DataGenerator_DatasetGenerator_R, sizeof(__pyx_k_DataGenerator_DatasetGenerator_R), 0, 0, 1, 1},
  {&__pyx_kp_s_DataGenerator_DatasetGenerator_R_2, __pyx_k_DataGenerator_DatasetGenerator_R_2, sizeof(__pyx_k_DataGenerator_DatasetGenerator_R_2), 0, 0, 1, 0},
  {&__pyx_n_s_RootWordDataSetGenerator, __pyx_k_RootWordDataSetGenerator, sizeof(__pyx_k_RootWordDataSetGenerator), 0, 0, 1, 1},
  {&__pyx_n_s_RootWordDataSetGenerator___init, __pyx_k_RootWordDataSetGenerator___init, sizeof(__pyx_k_RootWordDataSetGenerator___init), 0, 0, 1, 1},
  {&__pyx_n_u_RootWordInstanceGenerator, __pyx_k_RootWordInstanceGenerator, sizeof(__pyx_k_RootWordInstanceGenerator), 0, 1, 0, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_doc, __pyx_k_doc, sizeof(__pyx_k_doc), 0, 0, 1, 1},
  {&__pyx_n_s_folder, __pyx_k_folder, sizeof(__pyx_k_folder), 0, 0, 1, 1},
  {&__pyx_n_s_init, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_metaclass, __pyx_k_metaclass, sizeof(__pyx_k_metaclass), 0, 0, 1, 1},
  {&__pyx_n_s_module, __pyx_k_module, sizeof(__pyx_k_module), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_s_pattern, __pyx_k_pattern, sizeof(__pyx_k_pattern), 0, 0, 1, 1},
  {&__pyx_n_s_prepare, __pyx_k_prepare, sizeof(__pyx_k_prepare), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_qualname, __pyx_k_qualname, sizeof(__pyx_k_qualname), 0, 0, 1, 1},
  {&__pyx_n_s_rootWordInstanceGenerator, __pyx_k_rootWordInstanceGenerator, sizeof(__pyx_k_rootWordInstanceGenerator), 0, 0, 1, 1},
  {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
  {&__pyx_n_s_super, __pyx_k_super, sizeof(__pyx_k_super), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_u_unicode, __pyx_k_unicode, sizeof(__pyx_k_unicode), 0, 1, 0, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_super = __Pyx_GetBuiltinName(__pyx_n_s_super); if (!__pyx_builtin_super) __PYX_ERR(0, 21, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "DataGenerator/DatasetGenerator/RootWordDataSetGenerator.pyx":7
 * class RootWordDataSetGenerator(DataSetGenerator):
 * 
 *     def __init__(self, folder: str, pattern: str, rootWordInstanceGenerator: RootWordInstanceGenerator):             # <<<<<<<<<<<<<<
 *         """
 *         Constructor for the RootWordDataSetGenerator which takes input the data directory, the pattern for the training
 */
  __pyx_tuple_ = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_folder, __pyx_n_s_pattern, __pyx_n_s_rootWordInstanceGenerator); if (unlikely(!__pyx_tuple_)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);
  __pyx_codeobj__2 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple_, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_DataGenerator_DatasetGenerator_R_2, __pyx_n_s_init, 7, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__2)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule("Dictionary.Word"); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_10Dictionary_4Word_Word = __Pyx_ImportType(__pyx_t_1, "Dictionary.Word", "Word", sizeof(struct __pyx_obj_10Dictionary_4Word_Word), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_10Dictionary_4Word_Word) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_vtabptr_10Dictionary_4Word_Word = (struct __pyx_vtabstruct_10Dictionary_4Word_Word*)__Pyx_GetVtable(__pyx_ptype_10Dictionary_4Word_Word->tp_dict); if (unlikely(!__pyx_vtabptr_10Dictionary_4Word_Word)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("ParseTree.Symbol"); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_9ParseTree_6Symbol_Symbol = __Pyx_ImportType(__pyx_t_1, "ParseTree.Symbol", "Symbol", sizeof(struct __pyx_obj_9ParseTree_6Symbol_Symbol), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_9ParseTree_6Symbol_Symbol) __PYX_ERR(2, 4, __pyx_L1_error)
  __pyx_vtabptr_9ParseTree_6Symbol_Symbol = (struct __pyx_vtabstruct_9ParseTree_6Symbol_Symbol*)__Pyx_GetVtable(__pyx_ptype_9ParseTree_6Symbol_Symbol->tp_dict); if (unlikely(!__pyx_vtabptr_9ParseTree_6Symbol_Symbol)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("ParseTree.ParseNode"); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_9ParseTree_9ParseNode_ParseNode = __Pyx_ImportType(__pyx_t_1, "ParseTree.ParseNode", "ParseNode", sizeof(struct __pyx_obj_9ParseTree_9ParseNode_ParseNode), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_9ParseTree_9ParseNode_ParseNode) __PYX_ERR(3, 4, __pyx_L1_error)
  __pyx_vtabptr_9ParseTree_9ParseNode_ParseNode = (struct __pyx_vtabstruct_9ParseTree_9ParseNode_ParseNode*)__Pyx_GetVtable(__pyx_ptype_9ParseTree_9ParseNode_ParseNode->tp_dict); if (unlikely(!__pyx_vtabptr_9ParseTree_9ParseNode_ParseNode)) __PYX_ERR(3, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("ParseTree.ParseTree"); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_9ParseTree_9ParseTree_ParseTree = __Pyx_ImportType(__pyx_t_1, "ParseTree.ParseTree", "ParseTree", sizeof(struct __pyx_obj_9ParseTree_9ParseTree_ParseTree), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_9ParseTree_9ParseTree_ParseTree) __PYX_ERR(4, 4, __pyx_L1_error)
  __pyx_vtabptr_9ParseTree_9ParseTree_ParseTree = (struct __pyx_vtabstruct_9ParseTree_9ParseTree_ParseTree*)__Pyx_GetVtable(__pyx_ptype_9ParseTree_9ParseTree_ParseTree->tp_dict); if (unlikely(!__pyx_vtabptr_9ParseTree_9ParseTree_ParseTree)) __PYX_ERR(4, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Corpus.FileDescription"); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6Corpus_15FileDescription_FileDescription = __Pyx_ImportType(__pyx_t_1, "Corpus.FileDescription", "FileDescription", sizeof(struct __pyx_obj_6Corpus_15FileDescription_FileDescription), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_6Corpus_15FileDescription_FileDescription) __PYX_ERR(5, 1, __pyx_L1_error)
  __pyx_vtabptr_6Corpus_15FileDescription_FileDescription = (struct __pyx_vtabstruct_6Corpus_15FileDescription_FileDescription*)__Pyx_GetVtable(__pyx_ptype_6Corpus_15FileDescription_FileDescription->tp_dict); if (unlikely(!__pyx_vtabptr_6Corpus_15FileDescription_FileDescription)) __PYX_ERR(5, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Corpus.Sentence"); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6Corpus_8Sentence_Sentence = __Pyx_ImportType(__pyx_t_1, "Corpus.Sentence", "Sentence", sizeof(struct __pyx_obj_6Corpus_8Sentence_Sentence), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_6Corpus_8Sentence_Sentence) __PYX_ERR(6, 4, __pyx_L1_error)
  __pyx_vtabptr_6Corpus_8Sentence_Sentence = (struct __pyx_vtabstruct_6Corpus_8Sentence_Sentence*)__Pyx_GetVtable(__pyx_ptype_6Corpus_8Sentence_Sentence->tp_dict); if (unlikely(!__pyx_vtabptr_6Corpus_8Sentence_Sentence)) __PYX_ERR(6, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("DependencyParser.ParserEvaluationScore"); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore = __Pyx_ImportType(__pyx_t_1, "DependencyParser.ParserEvaluationScore", "ParserEvaluationScore", sizeof(struct __pyx_obj_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore) __PYX_ERR(7, 1, __pyx_L1_error)
  __pyx_vtabptr_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore = (struct __pyx_vtabstruct_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore*)__Pyx_GetVtable(__pyx_ptype_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore->tp_dict); if (unlikely(!__pyx_vtabptr_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore)) __PYX_ERR(7, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Dictionary.Trie.TrieNode"); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_10Dictionary_4Trie_8TrieNode_TrieNode = __Pyx_ImportType(__pyx_t_1, "Dictionary.Trie.TrieNode", "TrieNode", sizeof(struct __pyx_obj_10Dictionary_4Trie_8TrieNode_TrieNode), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_10Dictionary_4Trie_8TrieNode_TrieNode) __PYX_ERR(8, 4, __pyx_L1_error)
  __pyx_vtabptr_10Dictionary_4Trie_8TrieNode_TrieNode = (struct __pyx_vtabstruct_10Dictionary_4Trie_8TrieNode_TrieNode*)__Pyx_GetVtable(__pyx_ptype_10Dictionary_4Trie_8TrieNode_TrieNode->tp_dict); if (unlikely(!__pyx_vtabptr_10Dictionary_4Trie_8TrieNode_TrieNode)) __PYX_ERR(8, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Dictionary.TxtWord"); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_10Dictionary_7TxtWord_TxtWord = __Pyx_ImportType(__pyx_t_1, "Dictionary.TxtWord", "TxtWord", sizeof(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_10Dictionary_7TxtWord_TxtWord) __PYX_ERR(9, 4, __pyx_L1_error)
  __pyx_vtabptr_10Dictionary_7TxtWord_TxtWord = (struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord*)__Pyx_GetVtable(__pyx_ptype_10Dictionary_7TxtWord_TxtWord->tp_dict); if (unlikely(!__pyx_vtabptr_10Dictionary_7TxtWord_TxtWord)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Dictionary.Trie.Trie"); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_10Dictionary_4Trie_4Trie_Trie = __Pyx_ImportType(__pyx_t_1, "Dictionary.Trie.Trie", "Trie", sizeof(struct __pyx_obj_10Dictionary_4Trie_4Trie_Trie), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_10Dictionary_4Trie_4Trie_Trie) __PYX_ERR(10, 6, __pyx_L1_error)
  __pyx_vtabptr_10Dictionary_4Trie_4Trie_Trie = (struct __pyx_vtabstruct_10Dictionary_4Trie_4Trie_Trie*)__Pyx_GetVtable(__pyx_ptype_10Dictionary_4Trie_4Trie_Trie->tp_dict); if (unlikely(!__pyx_vtabptr_10Dictionary_4Trie_4Trie_Trie)) __PYX_ERR(10, 6, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Dictionary.Dictionary"); if (unlikely(!__pyx_t_1)) __PYX_ERR(11, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_10Dictionary_10Dictionary_Dictionary = __Pyx_ImportType(__pyx_t_1, "Dictionary.Dictionary", "Dictionary", sizeof(struct __pyx_obj_10Dictionary_10Dictionary_Dictionary), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_10Dictionary_10Dictionary_Dictionary) __PYX_ERR(11, 4, __pyx_L1_error)
  __pyx_vtabptr_10Dictionary_10Dictionary_Dictionary = (struct __pyx_vtabstruct_10Dictionary_10Dictionary_Dictionary*)__Pyx_GetVtable(__pyx_ptype_10Dictionary_10Dictionary_Dictionary->tp_dict); if (unlikely(!__pyx_vtabptr_10Dictionary_10Dictionary_Dictionary)) __PYX_ERR(11, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Dictionary.TxtDictionary"); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_10Dictionary_13TxtDictionary_TxtDictionary = __Pyx_ImportType(__pyx_t_1, "Dictionary.TxtDictionary", "TxtDictionary", sizeof(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_10Dictionary_13TxtDictionary_TxtDictionary) __PYX_ERR(12, 7, __pyx_L1_error)
  __pyx_vtabptr_10Dictionary_13TxtDictionary_TxtDictionary = (struct __pyx_vtabstruct_10Dictionary_13TxtDictionary_TxtDictionary*)__Pyx_GetVtable(__pyx_ptype_10Dictionary_13TxtDictionary_TxtDictionary->tp_dict); if (unlikely(!__pyx_vtabptr_10Dictionary_13TxtDictionary_TxtDictionary)) __PYX_ERR(12, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("DataStructure.Cache.LRUCache"); if (unlikely(!__pyx_t_1)) __PYX_ERR(13, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_13DataStructure_5Cache_8LRUCache_LRUCache = __Pyx_ImportType(__pyx_t_1, "DataStructure.Cache.LRUCache", "LRUCache", sizeof(struct __pyx_obj_13DataStructure_5Cache_8LRUCache_LRUCache), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_13DataStructure_5Cache_8LRUCache_LRUCache) __PYX_ERR(13, 1, __pyx_L1_error)
  __pyx_vtabptr_13DataStructure_5Cache_8LRUCache_LRUCache = (struct __pyx_vtabstruct_13DataStructure_5Cache_8LRUCache_LRUCache*)__Pyx_GetVtable(__pyx_ptype_13DataStructure_5Cache_8LRUCache_LRUCache->tp_dict); if (unlikely(!__pyx_vtabptr_13DataStructure_5Cache_8LRUCache_LRUCache)) __PYX_ERR(13, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.InflectionalGroup"); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.InflectionalGroup", "InflectionalGroup", sizeof(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup) __PYX_ERR(14, 1, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup = (struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup)) __PYX_ERR(14, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.MorphologicalParse"); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.MorphologicalParse", "MorphologicalParse", sizeof(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse) __PYX_ERR(15, 7, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse = (struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse)) __PYX_ERR(15, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.State"); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_5State_State = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.State", "State", sizeof(struct __pyx_obj_21MorphologicalAnalysis_5State_State), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_5State_State) __PYX_ERR(16, 1, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_5State_State = (struct __pyx_vtabstruct_21MorphologicalAnalysis_5State_State*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_5State_State->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_5State_State)) __PYX_ERR(16, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.FsmParse"); if (unlikely(!__pyx_t_1)) __PYX_ERR(17, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.FsmParse", "FsmParse", sizeof(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse) __PYX_ERR(17, 5, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_8FsmParse_FsmParse = (struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_8FsmParse_FsmParse)) __PYX_ERR(17, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.FiniteStateMachine"); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.FiniteStateMachine", "FiniteStateMachine", sizeof(struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine) __PYX_ERR(18, 4, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine = (struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine)) __PYX_ERR(18, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.MetamorphicParse"); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.MetamorphicParse", "MetamorphicParse", sizeof(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse) __PYX_ERR(19, 6, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse = (struct __pyx_vtabstruct_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse)) __PYX_ERR(19, 6, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.FsmMorphologicalAnalyzer"); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.FsmMorphologicalAnalyzer", "FsmMorphologicalAnalyzer", sizeof(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer) __PYX_ERR(20, 13, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer = (struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer)) __PYX_ERR(20, 13, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("PropBank.Frameset"); if (unlikely(!__pyx_t_1)) __PYX_ERR(21, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_8PropBank_8Frameset_Frameset = __Pyx_ImportType(__pyx_t_1, "PropBank.Frameset", "Frameset", sizeof(struct __pyx_obj_8PropBank_8Frameset_Frameset), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_8PropBank_8Frameset_Frameset) __PYX_ERR(21, 4, __pyx_L1_error)
  __pyx_vtabptr_8PropBank_8Frameset_Frameset = (struct __pyx_vtabstruct_8PropBank_8Frameset_Frameset*)__Pyx_GetVtable(__pyx_ptype_8PropBank_8Frameset_Frameset->tp_dict); if (unlikely(!__pyx_vtabptr_8PropBank_8Frameset_Frameset)) __PYX_ERR(21, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("PropBank.FramesetList"); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_8PropBank_12FramesetList_FramesetList = __Pyx_ImportType(__pyx_t_1, "PropBank.FramesetList", "FramesetList", sizeof(struct __pyx_obj_8PropBank_12FramesetList_FramesetList), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_8PropBank_12FramesetList_FramesetList) __PYX_ERR(22, 4, __pyx_L1_error)
  __pyx_vtabptr_8PropBank_12FramesetList_FramesetList = (struct __pyx_vtabstruct_8PropBank_12FramesetList_FramesetList*)__Pyx_GetVtable(__pyx_ptype_8PropBank_12FramesetList_FramesetList->tp_dict); if (unlikely(!__pyx_vtabptr_8PropBank_12FramesetList_FramesetList)) __PYX_ERR(22, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("FrameNet.Frame"); if (unlikely(!__pyx_t_1)) __PYX_ERR(23, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_8FrameNet_5Frame_Frame = __Pyx_ImportType(__pyx_t_1, "FrameNet.Frame", "Frame", sizeof(struct __pyx_obj_8FrameNet_5Frame_Frame), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_8FrameNet_5Frame_Frame) __PYX_ERR(23, 1, __pyx_L1_error)
  __pyx_vtabptr_8FrameNet_5Frame_Frame = (struct __pyx_vtabstruct_8FrameNet_5Frame_Frame*)__Pyx_GetVtable(__pyx_ptype_8FrameNet_5Frame_Frame->tp_dict); if (unlikely(!__pyx_vtabptr_8FrameNet_5Frame_Frame)) __PYX_ERR(23, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("FrameNet.FrameNet"); if (unlikely(!__pyx_t_1)) __PYX_ERR(24, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_8FrameNet_8FrameNet_FrameNet = __Pyx_ImportType(__pyx_t_1, "FrameNet.FrameNet", "FrameNet", sizeof(struct __pyx_obj_8FrameNet_8FrameNet_FrameNet), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_8FrameNet_8FrameNet_FrameNet) __PYX_ERR(24, 4, __pyx_L1_error)
  __pyx_vtabptr_8FrameNet_8FrameNet_FrameNet = (struct __pyx_vtabstruct_8FrameNet_8FrameNet_FrameNet*)__Pyx_GetVtable(__pyx_ptype_8FrameNet_8FrameNet_FrameNet->tp_dict); if (unlikely(!__pyx_vtabptr_8FrameNet_8FrameNet_FrameNet)) __PYX_ERR(24, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("WordNet.Relation"); if (unlikely(!__pyx_t_1)) __PYX_ERR(25, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7WordNet_8Relation_Relation = __Pyx_ImportType(__pyx_t_1, "WordNet.Relation", "Relation", sizeof(struct __pyx_obj_7WordNet_8Relation_Relation), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7WordNet_8Relation_Relation) __PYX_ERR(25, 1, __pyx_L1_error)
  __pyx_vtabptr_7WordNet_8Relation_Relation = (struct __pyx_vtabstruct_7WordNet_8Relation_Relation*)__Pyx_GetVtable(__pyx_ptype_7WordNet_8Relation_Relation->tp_dict); if (unlikely(!__pyx_vtabptr_7WordNet_8Relation_Relation)) __PYX_ERR(25, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("WordNet.Literal"); if (unlikely(!__pyx_t_1)) __PYX_ERR(26, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7WordNet_7Literal_Literal = __Pyx_ImportType(__pyx_t_1, "WordNet.Literal", "Literal", sizeof(struct __pyx_obj_7WordNet_7Literal_Literal), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7WordNet_7Literal_Literal) __PYX_ERR(26, 4, __pyx_L1_error)
  __pyx_vtabptr_7WordNet_7Literal_Literal = (struct __pyx_vtabstruct_7WordNet_7Literal_Literal*)__Pyx_GetVtable(__pyx_ptype_7WordNet_7Literal_Literal->tp_dict); if (unlikely(!__pyx_vtabptr_7WordNet_7Literal_Literal)) __PYX_ERR(26, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("WordNet.SemanticRelation"); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7WordNet_16SemanticRelation_SemanticRelation = __Pyx_ImportType(__pyx_t_1, "WordNet.SemanticRelation", "SemanticRelation", sizeof(struct __pyx_obj_7WordNet_16SemanticRelation_SemanticRelation), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7WordNet_16SemanticRelation_SemanticRelation) __PYX_ERR(27, 4, __pyx_L1_error)
  __pyx_vtabptr_7WordNet_16SemanticRelation_SemanticRelation = (struct __pyx_vtabstruct_7WordNet_16SemanticRelation_SemanticRelation*)__Pyx_GetVtable(__pyx_ptype_7WordNet_16SemanticRelation_SemanticRelation->tp_dict); if (unlikely(!__pyx_vtabptr_7WordNet_16SemanticRelation_SemanticRelation)) __PYX_ERR(27, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("WordNet.InterlingualRelation"); if (unlikely(!__pyx_t_1)) __PYX_ERR(28, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7WordNet_20InterlingualRelation_InterlingualRelation = __Pyx_ImportType(__pyx_t_1, "WordNet.InterlingualRelation", "InterlingualRelation", sizeof(struct __pyx_obj_7WordNet_20InterlingualRelation_InterlingualRelation), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7WordNet_20InterlingualRelation_InterlingualRelation) __PYX_ERR(28, 4, __pyx_L1_error)
  __pyx_vtabptr_7WordNet_20InterlingualRelation_InterlingualRelation = (struct __pyx_vtabstruct_7WordNet_20InterlingualRelation_InterlingualRelation*)__Pyx_GetVtable(__pyx_ptype_7WordNet_20InterlingualRelation_InterlingualRelation->tp_dict); if (unlikely(!__pyx_vtabptr_7WordNet_20InterlingualRelation_InterlingualRelation)) __PYX_ERR(28, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("WordNet.Synonym"); if (unlikely(!__pyx_t_1)) __PYX_ERR(29, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7WordNet_7Synonym_Synonym = __Pyx_ImportType(__pyx_t_1, "WordNet.Synonym", "Synonym", sizeof(struct __pyx_obj_7WordNet_7Synonym_Synonym), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7WordNet_7Synonym_Synonym) __PYX_ERR(29, 4, __pyx_L1_error)
  __pyx_vtabptr_7WordNet_7Synonym_Synonym = (struct __pyx_vtabstruct_7WordNet_7Synonym_Synonym*)__Pyx_GetVtable(__pyx_ptype_7WordNet_7Synonym_Synonym->tp_dict); if (unlikely(!__pyx_vtabptr_7WordNet_7Synonym_Synonym)) __PYX_ERR(29, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("WordNet.SynSet"); if (unlikely(!__pyx_t_1)) __PYX_ERR(30, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7WordNet_6SynSet_SynSet = __Pyx_ImportType(__pyx_t_1, "WordNet.SynSet", "SynSet", sizeof(struct __pyx_obj_7WordNet_6SynSet_SynSet), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7WordNet_6SynSet_SynSet) __PYX_ERR(30, 8, __pyx_L1_error)
  __pyx_vtabptr_7WordNet_6SynSet_SynSet = (struct __pyx_vtabstruct_7WordNet_6SynSet_SynSet*)__Pyx_GetVtable(__pyx_ptype_7WordNet_6SynSet_SynSet->tp_dict); if (unlikely(!__pyx_vtabptr_7WordNet_6SynSet_SynSet)) __PYX_ERR(30, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("WordNet.WordNet"); if (unlikely(!__pyx_t_1)) __PYX_ERR(31, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7WordNet_7WordNet_WordNet = __Pyx_ImportType(__pyx_t_1, "WordNet.WordNet", "WordNet", sizeof(struct __pyx_obj_7WordNet_7WordNet_WordNet), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7WordNet_7WordNet_WordNet) __PYX_ERR(31, 10, __pyx_L1_error)
  __pyx_vtabptr_7WordNet_7WordNet_WordNet = (struct __pyx_vtabstruct_7WordNet_7WordNet_WordNet*)__Pyx_GetVtable(__pyx_ptype_7WordNet_7WordNet_WordNet->tp_dict); if (unlikely(!__pyx_vtabptr_7WordNet_7WordNet_WordNet)) __PYX_ERR(31, 10, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("AnnotatedSentence.AnnotatedSentence"); if (unlikely(!__pyx_t_1)) __PYX_ERR(32, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence = __Pyx_ImportType(__pyx_t_1, "AnnotatedSentence.AnnotatedSentence", "AnnotatedSentence", sizeof(struct __pyx_obj_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence) __PYX_ERR(32, 9, __pyx_L1_error)
  __pyx_vtabptr_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence = (struct __pyx_vtabstruct_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence*)__Pyx_GetVtable(__pyx_ptype_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence->tp_dict); if (unlikely(!__pyx_vtabptr_17AnnotatedSentence_17AnnotatedSentence_AnnotatedSentence)) __PYX_ERR(32, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("AnnotatedTree.ParseTreeDrawable"); if (unlikely(!__pyx_t_1)) __PYX_ERR(33, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable = __Pyx_ImportType(__pyx_t_1, "AnnotatedTree.ParseTreeDrawable", "ParseTreeDrawable", sizeof(struct __pyx_obj_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable) __PYX_ERR(33, 8, __pyx_L1_error)
  __pyx_vtabptr_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable = (struct __pyx_vtabstruct_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable*)__Pyx_GetVtable(__pyx_ptype_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable->tp_dict); if (unlikely(!__pyx_vtabptr_13AnnotatedTree_17ParseTreeDrawable_ParseTreeDrawable)) __PYX_ERR(33, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("ParseTree.TreeBank"); if (unlikely(!__pyx_t_1)) __PYX_ERR(34, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_9ParseTree_8TreeBank_TreeBank = __Pyx_ImportType(__pyx_t_1, "ParseTree.TreeBank", "TreeBank", sizeof(struct __pyx_obj_9ParseTree_8TreeBank_TreeBank), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_9ParseTree_8TreeBank_TreeBank) __PYX_ERR(34, 4, __pyx_L1_error)
  __pyx_vtabptr_9ParseTree_8TreeBank_TreeBank = (struct __pyx_vtabstruct_9ParseTree_8TreeBank_TreeBank*)__Pyx_GetVtable(__pyx_ptype_9ParseTree_8TreeBank_TreeBank->tp_dict); if (unlikely(!__pyx_vtabptr_9ParseTree_8TreeBank_TreeBank)) __PYX_ERR(34, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("AnnotatedTree.TreeBankDrawable"); if (unlikely(!__pyx_t_1)) __PYX_ERR(35, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_13AnnotatedTree_16TreeBankDrawable_TreeBankDrawable = __Pyx_ImportType(__pyx_t_1, "AnnotatedTree.TreeBankDrawable", "TreeBankDrawable", sizeof(struct __pyx_obj_13AnnotatedTree_16TreeBankDrawable_TreeBankDrawable), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_13AnnotatedTree_16TreeBankDrawable_TreeBankDrawable) __PYX_ERR(35, 5, __pyx_L1_error)
  __pyx_vtabptr_13AnnotatedTree_16TreeBankDrawable_TreeBankDrawable = (struct __pyx_vtabstruct_13AnnotatedTree_16TreeBankDrawable_TreeBankDrawable*)__Pyx_GetVtable(__pyx_ptype_13AnnotatedTree_16TreeBankDrawable_TreeBankDrawable->tp_dict); if (unlikely(!__pyx_vtabptr_13AnnotatedTree_16TreeBankDrawable_TreeBankDrawable)) __PYX_ERR(35, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Classification.FeatureSelection.FeatureSubSet"); if (unlikely(!__pyx_t_1)) __PYX_ERR(36, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_14Classification_16FeatureSelection_13FeatureSubSet_FeatureSubSet = __Pyx_ImportType(__pyx_t_1, "Classification.FeatureSelection.FeatureSubSet", "FeatureSubSet", sizeof(struct __pyx_obj_14Classification_16FeatureSelection_13FeatureSubSet_FeatureSubSet), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_14Classification_16FeatureSelection_13FeatureSubSet_FeatureSubSet) __PYX_ERR(36, 1, __pyx_L1_error)
  __pyx_vtabptr_14Classification_16FeatureSelection_13FeatureSubSet_FeatureSubSet = (struct __pyx_vtabstruct_14Classification_16FeatureSelection_13FeatureSubSet_FeatureSubSet*)__Pyx_GetVtable(__pyx_ptype_14Classification_16FeatureSelection_13FeatureSubSet_FeatureSubSet->tp_dict); if (unlikely(!__pyx_vtabptr_14Classification_16FeatureSelection_13FeatureSubSet_FeatureSubSet)) __PYX_ERR(36, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Classification.Attribute.Attribute"); if (unlikely(!__pyx_t_1)) __PYX_ERR(37, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_14Classification_9Attribute_9Attribute_Attribute = __Pyx_ImportType(__pyx_t_1, "Classification.Attribute.Attribute", "Attribute", sizeof(struct __pyx_obj_14Classification_9Attribute_9Attribute_Attribute), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_14Classification_9Attribute_9Attribute_Attribute) __PYX_ERR(37, 1, __pyx_L1_error)
  __pyx_vtabptr_14Classification_9Attribute_9Attribute_Attribute = (struct __pyx_vtabstruct_14Classification_9Attribute_9Attribute_Attribute*)__Pyx_GetVtable(__pyx_ptype_14Classification_9Attribute_9Attribute_Attribute->tp_dict); if (unlikely(!__pyx_vtabptr_14Classification_9Attribute_9Attribute_Attribute)) __PYX_ERR(37, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Math.Vector"); if (unlikely(!__pyx_t_1)) __PYX_ERR(38, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_4Math_6Vector_Vector = __Pyx_ImportType(__pyx_t_1, "Math.Vector", "Vector", sizeof(struct __pyx_obj_4Math_6Vector_Vector), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_4Math_6Vector_Vector) __PYX_ERR(38, 1, __pyx_L1_error)
  __pyx_vtabptr_4Math_6Vector_Vector = (struct __pyx_vtabstruct_4Math_6Vector_Vector*)__Pyx_GetVtable(__pyx_ptype_4Math_6Vector_Vector->tp_dict); if (unlikely(!__pyx_vtabptr_4Math_6Vector_Vector)) __PYX_ERR(38, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Classification.Instance.Instance"); if (unlikely(!__pyx_t_1)) __PYX_ERR(39, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_14Classification_8Instance_8Instance_Instance = __Pyx_ImportType(__pyx_t_1, "Classification.Instance.Instance", "Instance", sizeof(struct __pyx_obj_14Classification_8Instance_8Instance_Instance), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_14Classification_8Instance_8Instance_Instance) __PYX_ERR(39, 6, __pyx_L1_error)
  __pyx_vtabptr_14Classification_8Instance_8Instance_Instance = (struct __pyx_vtabstruct_14Classification_8Instance_8Instance_Instance*)__Pyx_GetVtable(__pyx_ptype_14Classification_8Instance_8Instance_Instance->tp_dict); if (unlikely(!__pyx_vtabptr_14Classification_8Instance_8Instance_Instance)) __PYX_ERR(39, 6, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Sampling.Bootstrap"); if (unlikely(!__pyx_t_1)) __PYX_ERR(40, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_8Sampling_9Bootstrap_Bootstrap = __Pyx_ImportType(__pyx_t_1, "Sampling.Bootstrap", "Bootstrap", sizeof(struct __pyx_obj_8Sampling_9Bootstrap_Bootstrap), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_8Sampling_9Bootstrap_Bootstrap) __PYX_ERR(40, 1, __pyx_L1_error)
  __pyx_vtabptr_8Sampling_9Bootstrap_Bootstrap = (struct __pyx_vtabstruct_8Sampling_9Bootstrap_Bootstrap*)__Pyx_GetVtable(__pyx_ptype_8Sampling_9Bootstrap_Bootstrap->tp_dict); if (unlikely(!__pyx_vtabptr_8Sampling_9Bootstrap_Bootstrap)) __PYX_ERR(40, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Math.DiscreteDistribution"); if (unlikely(!__pyx_t_1)) __PYX_ERR(41, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_4Math_20DiscreteDistribution_DiscreteDistribution = __Pyx_ImportType(__pyx_t_1, "Math.DiscreteDistribution", "DiscreteDistribution", sizeof(struct __pyx_obj_4Math_20DiscreteDistribution_DiscreteDistribution), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_4Math_20DiscreteDistribution_DiscreteDistribution) __PYX_ERR(41, 1, __pyx_L1_error)
  __pyx_vtabptr_4Math_20DiscreteDistribution_DiscreteDistribution = (struct __pyx_vtabstruct_4Math_20DiscreteDistribution_DiscreteDistribution*)__Pyx_GetVtable(__pyx_ptype_4Math_20DiscreteDistribution_DiscreteDistribution->tp_dict); if (unlikely(!__pyx_vtabptr_4Math_20DiscreteDistribution_DiscreteDistribution)) __PYX_ERR(41, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Math.Matrix"); if (unlikely(!__pyx_t_1)) __PYX_ERR(42, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_4Math_6Matrix_Matrix = __Pyx_ImportType(__pyx_t_1, "Math.Matrix", "Matrix", sizeof(struct __pyx_obj_4Math_6Matrix_Matrix), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_4Math_6Matrix_Matrix) __PYX_ERR(42, 4, __pyx_L1_error)
  __pyx_vtabptr_4Math_6Matrix_Matrix = (struct __pyx_vtabstruct_4Math_6Matrix_Matrix*)__Pyx_GetVtable(__pyx_ptype_4Math_6Matrix_Matrix->tp_dict); if (unlikely(!__pyx_vtabptr_4Math_6Matrix_Matrix)) __PYX_ERR(42, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Classification.InstanceList.InstanceList"); if (unlikely(!__pyx_t_1)) __PYX_ERR(43, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_14Classification_12InstanceList_12InstanceList_InstanceList = __Pyx_ImportType(__pyx_t_1, "Classification.InstanceList.InstanceList", "InstanceList", sizeof(struct __pyx_obj_14Classification_12InstanceList_12InstanceList_InstanceList), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_14Classification_12InstanceList_12InstanceList_InstanceList) __PYX_ERR(43, 9, __pyx_L1_error)
  __pyx_vtabptr_14Classification_12InstanceList_12InstanceList_InstanceList = (struct __pyx_vtabstruct_14Classification_12InstanceList_12InstanceList_InstanceList*)__Pyx_GetVtable(__pyx_ptype_14Classification_12InstanceList_12InstanceList_InstanceList->tp_dict); if (unlikely(!__pyx_vtabptr_14Classification_12InstanceList_12InstanceList_InstanceList)) __PYX_ERR(43, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Classification.DataSet.DataDefinition"); if (unlikely(!__pyx_t_1)) __PYX_ERR(44, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_14Classification_7DataSet_14DataDefinition_DataDefinition = __Pyx_ImportType(__pyx_t_1, "Classification.DataSet.DataDefinition", "DataDefinition", sizeof(struct __pyx_obj_14Classification_7DataSet_14DataDefinition_DataDefinition), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_14Classification_7DataSet_14DataDefinition_DataDefinition) __PYX_ERR(44, 4, __pyx_L1_error)
  __pyx_vtabptr_14Classification_7DataSet_14DataDefinition_DataDefinition = (struct __pyx_vtabstruct_14Classification_7DataSet_14DataDefinition_DataDefinition*)__Pyx_GetVtable(__pyx_ptype_14Classification_7DataSet_14DataDefinition_DataDefinition->tp_dict); if (unlikely(!__pyx_vtabptr_14Classification_7DataSet_14DataDefinition_DataDefinition)) __PYX_ERR(44, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Classification.DataSet.DataSet"); if (unlikely(!__pyx_t_1)) __PYX_ERR(45, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_14Classification_7DataSet_7DataSet_DataSet = __Pyx_ImportType(__pyx_t_1, "Classification.DataSet.DataSet", "DataSet", sizeof(struct __pyx_obj_14Classification_7DataSet_7DataSet_DataSet), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_14Classification_7DataSet_7DataSet_DataSet) __PYX_ERR(45, 7, __pyx_L1_error)
  __pyx_vtabptr_14Classification_7DataSet_7DataSet_DataSet = (struct __pyx_vtabstruct_14Classification_7DataSet_7DataSet_DataSet*)__Pyx_GetVtable(__pyx_ptype_14Classification_7DataSet_7DataSet_DataSet->tp_dict); if (unlikely(!__pyx_vtabptr_14Classification_7DataSet_7DataSet_DataSet)) __PYX_ERR(45, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("DataGenerator.InstanceGenerator.InstanceGenerator"); if (unlikely(!__pyx_t_1)) __PYX_ERR(46, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_13DataGenerator_17InstanceGenerator_17InstanceGenerator_InstanceGenerator = __Pyx_ImportType(__pyx_t_1, "DataGenerator.InstanceGenerator.InstanceGenerator", "InstanceGenerator", sizeof(struct __pyx_obj_13DataGenerator_17InstanceGenerator_17InstanceGenerator_InstanceGenerator), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_13DataGenerator_17InstanceGenerator_17InstanceGenerator_InstanceGenerator) __PYX_ERR(46, 5, __pyx_L1_error)
  __pyx_vtabptr_13DataGenerator_17InstanceGenerator_17InstanceGenerator_InstanceGenerator = (struct __pyx_vtabstruct_13DataGenerator_17InstanceGenerator_17InstanceGenerator_InstanceGenerator*)__Pyx_GetVtable(__pyx_ptype_13DataGenerator_17InstanceGenerator_17InstanceGenerator_InstanceGenerator->tp_dict); if (unlikely(!__pyx_vtabptr_13DataGenerator_17InstanceGenerator_17InstanceGenerator_InstanceGenerator)) __PYX_ERR(46, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("DataGenerator.DatasetGenerator.DataSetGenerator"); if (unlikely(!__pyx_t_1)) __PYX_ERR(47, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_13DataGenerator_16DatasetGenerator_16DataSetGenerator_DataSetGenerator = __Pyx_ImportType(__pyx_t_1, "DataGenerator.DatasetGenerator.DataSetGenerator", "DataSetGenerator", sizeof(struct __pyx_obj_13DataGenerator_16DatasetGenerator_16DataSetGenerator_DataSetGenerator), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_13DataGenerator_16DatasetGenerator_16DataSetGenerator_DataSetGenerator) __PYX_ERR(47, 7, __pyx_L1_error)
  __pyx_vtabptr_13DataGenerator_16DatasetGenerator_16DataSetGenerator_DataSetGenerator = (struct __pyx_vtabstruct_13DataGenerator_16DatasetGenerator_16DataSetGenerator_DataSetGenerator*)__Pyx_GetVtable(__pyx_ptype_13DataGenerator_16DatasetGenerator_16DataSetGenerator_DataSetGenerator->tp_dict); if (unlikely(!__pyx_vtabptr_13DataGenerator_16DatasetGenerator_16DataSetGenerator_DataSetGenerator)) __PYX_ERR(47, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("DataGenerator.InstanceGenerator.RootWordInstanceGenerator"); if (unlikely(!__pyx_t_1)) __PYX_ERR(48, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_13DataGenerator_17InstanceGenerator_25RootWordInstanceGenerator_RootWordInstanceGenerator = __Pyx_ImportType(__pyx_t_1, "DataGenerator.InstanceGenerator.RootWordInstanceGenerator", "RootWordInstanceGenerator", sizeof(struct __pyx_obj_13DataGenerator_17InstanceGenerator_25RootWordInstanceGenerator_RootWordInstanceGenerator), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_13DataGenerator_17InstanceGenerator_25RootWordInstanceGenerator_RootWordInstanceGenerator) __PYX_ERR(48, 6, __pyx_L1_error)
  __pyx_vtabptr_13DataGenerator_17InstanceGenerator_25RootWordInstanceGenerator_RootWordInstanceGenerator = (struct __pyx_vtabstruct_13DataGenerator_17InstanceGenerator_25RootWordInstanceGenerator_RootWordInstanceGenerator*)__Pyx_GetVtable(__pyx_ptype_13DataGenerator_17InstanceGenerator_25RootWordInstanceGenerator_RootWordInstanceGenerator->tp_dict); if (unlikely(!__pyx_vtabptr_13DataGenerator_17InstanceGenerator_25RootWordInstanceGenerator_RootWordInstanceGenerator)) __PYX_ERR(48, 6, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initRootWordDataSetGenerator(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initRootWordDataSetGenerator(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_RootWordDataSetGenerator(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_RootWordDataSetGenerator(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_RootWordDataSetGenerator(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'RootWordDataSetGenerator' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_RootWordDataSetGenerator(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("RootWordDataSetGenerator", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_DataGenerator__DatasetGenerator__RootWordDataSetGenerator) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "DataGenerator.DatasetGenerator.RootWordDataSetGenerator")) {
      if (unlikely(PyDict_SetItemString(modules, "DataGenerator.DatasetGenerator.RootWordDataSetGenerator", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  (void)__Pyx_modinit_type_init_code();
  if (unlikely(__Pyx_modinit_type_import_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "DataGenerator/DatasetGenerator/RootWordDataSetGenerator.pyx":5
 * 
 * 
 * class RootWordDataSetGenerator(DataSetGenerator):             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, folder: str, pattern: str, rootWordInstanceGenerator: RootWordInstanceGenerator):
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_ptype_13DataGenerator_16DatasetGenerator_16DataSetGenerator_DataSetGenerator));
  __Pyx_GIVEREF(((PyObject *)__pyx_ptype_13DataGenerator_16DatasetGenerator_16DataSetGenerator_DataSetGenerator));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_ptype_13DataGenerator_16DatasetGenerator_16DataSetGenerator_DataSetGenerator));
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_1, __pyx_n_s_RootWordDataSetGenerator, __pyx_n_s_RootWordDataSetGenerator, (PyObject *) NULL, __pyx_n_s_DataGenerator_DatasetGenerator_R, (PyObject *) NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "DataGenerator/DatasetGenerator/RootWordDataSetGenerator.pyx":7
 * class RootWordDataSetGenerator(DataSetGenerator):
 * 
 *     def __init__(self, folder: str, pattern: str, rootWordInstanceGenerator: RootWordInstanceGenerator):             # <<<<<<<<<<<<<<
 *         """
 *         Constructor for the RootWordDataSetGenerator which takes input the data directory, the pattern for the training
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_folder, __pyx_n_u_unicode) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_pattern, __pyx_n_u_unicode) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_rootWordInstanceGenerator, __pyx_n_u_RootWordInstanceGenerator) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_13DataGenerator_16DatasetGenerator_24RootWordDataSetGenerator_24RootWordDataSetGenerator_1__init__, 0, __pyx_n_s_RootWordDataSetGenerator___init, NULL, __pyx_n_s_DataGenerator_DatasetGenerator_R, __pyx_d, ((PyObject *)__pyx_codeobj__2)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_t_6);
  PyList_Append(__pyx_t_4, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_init, __pyx_t_6) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "DataGenerator/DatasetGenerator/RootWordDataSetGenerator.pyx":5
 * 
 * 
 * class RootWordDataSetGenerator(DataSetGenerator):             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, folder: str, pattern: str, rootWordInstanceGenerator: RootWordInstanceGenerator):
 */
  __pyx_t_6 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_RootWordDataSetGenerator, __pyx_t_1, __pyx_t_3, NULL, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_CyFunction_InitClassCell(__pyx_t_4, __pyx_t_6) < 0) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_RootWordDataSetGenerator, __pyx_t_6) < 0) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "DataGenerator/DatasetGenerator/RootWordDataSetGenerator.pyx":1
 * from DataGenerator.DatasetGenerator.DataSetGenerator cimport DataSetGenerator             # <<<<<<<<<<<<<<
 * from DataGenerator.InstanceGenerator.RootWordInstanceGenerator cimport RootWordInstanceGenerator
 * 
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_1) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init DataGenerator.DatasetGenerator.RootWordDataSetGenerator", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_CLEAR(__pyx_m);
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init DataGenerator.DatasetGenerator.RootWordDataSetGenerator");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected %.200s, got %.200s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
    return 0;
}

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyCFunctionFastCall */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)(void*)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)(void*)meth)) (self, args, nargs);
    }
}
#endif

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(PyObject *module, const char *module_name, const char *class_name,
    size_t size, enum __Pyx_ImportType_CheckSize check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if ((size_t)basicsize < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error && (size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* GetVTable */
static void* __Pyx_GetVtable(PyObject *dict) {
    void* ptr;
    PyObject *ob = PyObject_GetItem(dict, __pyx_n_s_pyx_vtable);
    if (!ob)
        goto bad;
#if PY_VERSION_HEX >= 0x02070000
    ptr = PyCapsule_GetPointer(ob, 0);
#else
    ptr = PyCObject_AsVoidPtr(ob);
#endif
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* CalculateMetaclass */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases = PyTuple_GET_SIZE(bases);
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
        tmptype = Py_TYPE(tmp);
#if PY_MAJOR_VERSION < 3
        if (tmptype == &PyClass_Type)
            continue;
#endif
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
#if PY_MAJOR_VERSION < 3
        metaclass = &PyClass_Type;
#else
        metaclass = &PyType_Type;
#endif
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* FetchCommonType */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* fake_module;
    PyTypeObject* cached_type = NULL;
    fake_module = PyImport_AddModule((char*) "_cython_" CYTHON_ABI);
    if (!fake_module) return NULL;
    Py_INCREF(fake_module);
    cached_type = (PyTypeObject*) PyObject_GetAttrString(fake_module, type->tp_name);
    if (cached_type) {
        if (!PyType_Check((PyObject*)cached_type)) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s is not a type object",
                type->tp_name);
            goto bad;
        }
        if (cached_type->tp_basicsize != type->tp_basicsize) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s has the wrong size, try recompiling",
                type->tp_name);
            goto bad;
        }
    } else {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
        PyErr_Clear();
        if (PyType_Ready(type) < 0) goto bad;
        if (PyObject_SetAttrString(fake_module, type->tp_name, (PyObject*) type) < 0)
            goto bad;
        Py_INCREF(type);
        cached_type = type;
    }
done:
    Py_DECREF(fake_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CythonFunctionShared */
#include <structmember.h>
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *closure)
{
    if (unlikely(op->func_doc == NULL)) {
        if (op->func.m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(op->func.m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(op->func.m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp = op->func_doc;
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    op->func_doc = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    if (unlikely(op->func_name == NULL)) {
#if PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(op->func.m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(op->func.m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = op->func_name;
    Py_INCREF(value);
    op->func_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = op->func_qualname;
    Py_INCREF(value);
    op->func_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_self(__pyx_CyFunctionObject *m, CYTHON_UNUSED void *closure)
{
    PyObject *self;
    self = m->func_closure;
    if (self == NULL)
        self = Py_None;
    Py_INCREF(self);
    return self;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    tmp = op->func_dict;
    Py_INCREF(value);
    op->func_dict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(CYTHON_UNUSED __pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyTuple_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_tuple;
    op->defaults_tuple = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_kwdict;
    op->defaults_kwdict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value || value == Py_None) {
        value = NULL;
    } else if (!PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    tmp = op->func_annotations;
    op->func_annotations = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "__self__", (getter)__Pyx_CyFunction_get_self, 0, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), PY_WRITE_RESTRICTED, 0},
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, CYTHON_UNUSED PyObject *args)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromString(m->func.m_ml->ml_name);
#else
    return PyString_FromString(m->func.m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func.m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    if (unlikely(op == NULL))
        return NULL;
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
    op->func.m_ml = ml;
    op->func.m_self = (PyObject *) op;
    Py_XINCREF(closure);
    op->func_closure = closure;
    Py_XINCREF(module);
    op->func.m_module = module;
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
    op->func_classobj = NULL;
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults_size = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
    Py_CLEAR(m->func.m_module);
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
    Py_CLEAR(m->func_classobj);
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    PyObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
    Py_VISIT(m->func.m_module);
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
    Py_VISIT(m->func_classobj);
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject *__Pyx_CyFunction_descr_get(PyObject *func, PyObject *obj, PyObject *type)
{
#if PY_MAJOR_VERSION < 3
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    if (m->flags & __Pyx_CYFUNCTION_STATICMETHOD) {
        Py_INCREF(func);
        return func;
    }
    if (m->flags & __Pyx_CYFUNCTION_CLASSMETHOD) {
        if (type == NULL)
            type = (PyObject *)(Py_TYPE(obj));
        return __Pyx_PyMethod_New(func, type, (PyObject *)(Py_TYPE(type)));
    }
    if (obj == Py_None)
        obj = NULL;
#endif
    return __Pyx_PyMethod_New(func, obj, type);
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    Py_ssize_t size;
    switch (f->m_ml->ml_flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 0))
                return (*meth)(self, NULL);
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags in "
                        "__Pyx_CyFunction_Call. METH_OLDARGS is no "
                        "longer supported!");
        return NULL;
    }
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    return __Pyx_CyFunction_CallMethod(func, ((PyCFunctionObject*)func)->m_self, arg, kw);
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
        argc = PyTuple_GET_SIZE(args);
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
    0,
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_CyFunction_descr_get,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
    0,
#endif
};
static int __pyx_CyFunction_init(void) {
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    m->defaults_size = size;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* Py3ClassCreate */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStr(metaclass, __pyx_n_s_prepare);
        if (prep) {
            PyObject *pargs = PyTuple_Pack(2, name, bases);
            if (unlikely(!pargs)) {
                Py_DECREF(prep);
                return NULL;
            }
            ns = PyObject_Call(prep, pargs, mkw);
            Py_DECREF(prep);
            Py_DECREF(pargs);
        } else {
            if (unlikely(!PyErr_ExceptionMatches(PyExc_AttributeError)))
                return NULL;
            PyErr_Clear();
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_module, modname) < 0)) goto bad;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_qualname, qualname) < 0)) goto bad;
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_n_s_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result, *margs;
    PyObject *owned_metaclass = NULL;
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_n_s_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    margs = PyTuple_Pack(3, name, bases, dict);
    if (unlikely(!margs)) {
        result = NULL;
    } else {
        result = PyObject_Call(metaclass, margs, mkw);
        Py_DECREF(margs);
    }
    Py_XDECREF(owned_metaclass);
    return result;
}

/* CyFunctionClassCell */
static int __Pyx_CyFunction_InitClassCell(PyObject *cyfunctions, PyObject *classobj) {
    Py_ssize_t i, count = PyList_GET_SIZE(cyfunctions);
    for (i = 0; i < count; i++) {
        __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *)
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            PyList_GET_ITEM(cyfunctions, i);
#else
            PySequence_ITEM(cyfunctions, i);
        if (unlikely(!m))
            return -1;
#endif
        Py_INCREF(classobj);
        m->func_classobj = classobj;
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
        Py_DECREF((PyObject*)m);
#endif
    }
    return 0;
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_NCP_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) ((int) 0 - (int) 1), const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
